(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    236403,       6477]
NotebookOptionsPosition[    231867,       6389]
NotebookOutlinePosition[    232335,       6407]
CellTagsIndexPosition[    232292,       6404]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Low-Deborah-number analysis up to ",
 Cell[BoxData[
  FormBox[
   RowBox[{"O", "(", 
    SuperscriptBox["De", "4"], ")"}], TraditionalForm]],
  FormatType->TraditionalForm,ExpressionUUID->
  "e37df667-383c-4f3a-bccb-ea471ddf9c17"]
}], "Title",
 CellChangeTimes->{{3.93078411013509*^9, 
  3.9307841642472744`*^9}},ExpressionUUID->"dbc62d93-449a-4266-8f5f-\
1c83689d4c88"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Explanation", " ", "of", " ", "various", " ", "parameters", " ", "used", 
    " ", "in", " ", "the", " ", "present", " ", "analysis"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"H", "[", "Z", "]"}], " ", "is", " ", "the", " ", "shape", " ", 
    "function", " ", "of", " ", "a", " ", "slowly", " ", "varying", " ", 
    "channel"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "\[Beta]t", " ", "is", " ", "the", " ", "viscosity", " ", "ratio", " ", 
    "defined", " ", "by", " ", "the", " ", "ratio", " ", "of", " ", "polymer",
     " ", "viscosity", " ", "to", " ", "the", " ", "total", " ", "viscosity", 
    " ", "defined", " ", "in", " ", 
    RowBox[{"Eq", ".", 
     RowBox[{"(", "2.9", ")"}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
     "Leps2", " ", "is", " ", "the", " ", "finite", " ", "extensibility", " ",
       "of", " ", "the", " ", "FENE"}], "-", 
     RowBox[{"CR", " ", "fluid", " ", "defined", " ", "as", " ", "Leps2"}]}], 
    "=", 
    RowBox[{
     SuperscriptBox["L", "2"], 
     SuperscriptBox["\[Epsilon]", "2"]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "AUXzz", " ", "and", " ", "AUXyz", " ", "are", " ", "defined", " ", "as", 
    " ", "auxiliary", " ", "functions", " ", "used", " ", "to", " ", 
    "calculate", " ", "the", " ", "velocity", " ", "and", " ", "pressure"}], 
   " ", "*)"}]}]], "Text",
 CellChangeTimes->{{3.9236233579700823`*^9, 3.9236234095292935`*^9}, {
   3.9236235587561393`*^9, 3.92362358649539*^9}, {3.9236236562237654`*^9, 
   3.9236238192437553`*^9}, {3.9236238623305583`*^9, 3.923623909384939*^9}, {
   3.92362433525348*^9, 3.923624336994402*^9}, {3.923624660022287*^9, 
   3.923624683286965*^9}, {3.9236290162713184`*^9, 3.9236290413792844`*^9}, {
   3.9236519912144213`*^9, 3.9236520387349863`*^9}, 3.9238762952928286`*^9, {
   3.9238874014774127`*^9, 3.923887407422003*^9}, {3.924303555405067*^9, 
   3.924303601505042*^9}, {3.9245167392359147`*^9, 3.9245167579448986`*^9}, 
   3.9245173021747637`*^9, {3.930553858903824*^9, 3.930553859282653*^9}, {
   3.930784099851918*^9, 
   3.930784105927807*^9}},ExpressionUUID->"42b92100-7780-43c5-94be-\
ff71f092ad71"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Leading-order solution FENE-CR", "Title",
 CellChangeTimes->{{3.9015050076180925`*^9, 3.9015050356354923`*^9}, {
  3.901506936799791*^9, 3.9015069501055136`*^9}, {3.9015097545317197`*^9, 
  3.9015097580926886`*^9}},ExpressionUUID->"a5a05402-7c96-45c6-924a-\
d2888b544da6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Azz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     SubscriptBox["\[PartialD]", "Y"], " ", 
     RowBox[{"Uz0", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"2", "*", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Pgrad0", "[", "Z", "]"}], "==", 
        RowBox[{
         RowBox[{"Uz0", "''"}], "[", "Y", "]"}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Uz0", "'"}], "[", "0", "]"}], "==", "0"}], ",", 
       RowBox[{
        RowBox[{"Uz0", "[", 
         RowBox[{"H", "[", "Z", "]"}], "]"}], "==", "0"}]}], "}"}], ",", 
     RowBox[{"Uz0", "[", "Y", "]"}], ",", "Y"}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     FractionBox["1", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["Y", "2"], "-", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
     RowBox[{"Pgrad0", "[", "Z", "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"H", "[", "Z", "]"}]], 
      RowBox[{
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}], "==", "1"}], ",", 
    RowBox[{"Pgrad0", "[", "Z", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pgrad0", "[", "Z_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     FractionBox["3", 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "3"]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubscriptBox["\[PartialD]", "Z"], " ", 
    RowBox[{"Uz0", "[", 
     RowBox[{"Y", ",", "Z"}], "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "Y"], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uz0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Uz0", "[", 
    RowBox[{"Y", ",", "Z"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Uy0", "[", 
    RowBox[{"Y", ",", "Z"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dP0", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Pgrad0", "[", "Z", "]"}]}], 
       RowBox[{"\[DifferentialD]", "Z"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Final", " ", "expression", " ", "for", " ", "the", " ", "leading"}], "-", 
    RowBox[{
    "order", " ", "pressure", " ", "drop", " ", "after", " ", 
     "simplifications"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dP0Final", "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      FractionBox["3", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "3"]], 
      RowBox[{"\[DifferentialD]", "Z"}]}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "To", " ", "check", " ", "the", " ", "consistency", " ", "of", " ", "our", 
    " ", "solution", " ", "and", " ", "final", " ", "expression", " ", "at", 
    " ", "leading", " ", "order"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"dP0", "-", "dP0Final"}], "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.901505053288396*^9, {3.9015059034118013`*^9, 3.901505958076338*^9}, {
   3.901506004238992*^9, 3.9015060432379203`*^9}, {3.9015060942828784`*^9, 
   3.901506125293334*^9}, {3.901506223405347*^9, 3.90150622714672*^9}, {
   3.90150637553543*^9, 3.9015063854831567`*^9}, {3.901506421611328*^9, 
   3.9015064277776685`*^9}, {3.901506551276746*^9, 3.901506696790374*^9}, {
   3.901507833590026*^9, 3.901507836573123*^9}, {3.9042734558423195`*^9, 
   3.904273460486746*^9}, {3.913701690505189*^9, 3.913701709456061*^9}, {
   3.9230446364003406`*^9, 3.9230447427207727`*^9}, {3.9230447869604435`*^9, 
   3.923044897334988*^9}, {3.9230449294151673`*^9, 3.923044931639267*^9}, {
   3.9230450071505775`*^9, 3.923045039661915*^9}, {3.9230450783257327`*^9, 
   3.9230450787650013`*^9}, 3.923045165748601*^9, {3.9230452009305677`*^9, 
   3.923045224964527*^9}, {3.9230453496990614`*^9, 3.923045373498331*^9}, {
   3.9230454426924934`*^9, 3.923045506060584*^9}, {3.9230456233402553`*^9, 
   3.923045693555805*^9}, {3.923045763774222*^9, 3.923045812689274*^9}, {
   3.9230458501037545`*^9, 3.923045858538641*^9}, {3.923045892774598*^9, 
   3.923046118661127*^9}, {3.9232745740337324`*^9, 3.923274614350132*^9}, 
   3.9232895023816247`*^9, {3.923535680584936*^9, 3.9235356981302347`*^9}, {
   3.923535730211065*^9, 3.923535742377221*^9}, {3.923535786884771*^9, 
   3.923535790239755*^9}, {3.923535914846773*^9, 3.923535918371179*^9}, 
   3.923554706518301*^9, {3.923876227704556*^9, 3.923876279333769*^9}, {
   3.9239020139689517`*^9, 3.9239020604082575`*^9}, {3.923902211777768*^9, 
   3.923902269977639*^9}, {3.9239027178098717`*^9, 3.9239027358571763`*^9}, {
   3.9245167794996586`*^9, 3.9245167799209003`*^9}, 3.9245170534528475`*^9, {
   3.924851556870412*^9, 3.9248515643350315`*^9}, {3.930784177388688*^9, 
   3.930784178430227*^9}},ExpressionUUID->"830a6b97-8ec7-4883-adfc-\
d60dd038f50b"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.9230447592352505`*^9, {3.923044910934033*^9, 3.9230449599149218`*^9}, 
   3.92304504636334*^9, {3.923045169782278*^9, 3.9230452329260097`*^9}, 
   3.9230454465688295`*^9, {3.923045497910754*^9, 3.923045517104746*^9}, 
   3.9230456205118666`*^9, 3.9230456974975843`*^9, 3.9230458280910115`*^9, 
   3.9230458675840025`*^9, {3.9230459100309663`*^9, 3.9230459288092213`*^9}, 
   3.9230459710343237`*^9, {3.9230460204168367`*^9, 3.923046087604396*^9}, 
   3.923046128219925*^9, 3.923274571757492*^9, 3.9232895138611126`*^9, 
   3.9235357535201674`*^9, 3.923535799672032*^9, 3.923535932020233*^9, 
   3.92387625449238*^9, 3.9238762861956744`*^9, 3.923902283056531*^9, 
   3.9306504767948337`*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"e326d2cf-f52c-41c9-9d28-51d4908e1e99"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["First-order solution FENE-CR", "Title",
 CellChangeTimes->{{3.9015069199705796`*^9, 3.901506956197323*^9}, {
  3.901510063361582*^9, 
  3.901510067689316*^9}},ExpressionUUID->"87b5e66b-9103-4afc-9346-\
b706941f3a0b"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Uz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["Y", "2"], "-", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "3"]}]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"3", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["Y", "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "Z", "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "4"]}]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     SubscriptBox["\[PartialD]", "Y"], " ", 
     RowBox[{"Uz0", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"2", "*", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"2", "*", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
     RowBox[{"Ayz1", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Ayy2", "[", 
     RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Uz0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Ayy1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Ayy1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uy0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Auxiliary", " ", "function", " ", "used", " ", "to", " ", "calculate", 
    " ", "the", " ", "velocity", " ", "and", " ", "pressure"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AUXzz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Azz2", "[", 
     RowBox[{"Y", ",", "Z"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AUXyz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Ayz2", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}], "-", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Pgrad1", "[", "Z", "]"}], "==", 
        RowBox[{
         RowBox[{
          RowBox[{"Uz1", "''"}], "[", "Y", "]"}], "+", 
         RowBox[{"\[Beta]t", "*", 
          RowBox[{
           SubscriptBox["\[PartialD]", "Z"], " ", 
           RowBox[{"AUXzz2", "[", 
            RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
         RowBox[{"\[Beta]t", "*", 
          RowBox[{
           SubscriptBox["\[PartialD]", "Y"], " ", 
           RowBox[{"AUXyz2", "[", 
            RowBox[{"Y", ",", "Z"}], "]"}]}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Uz1", "'"}], "[", "0", "]"}], "==", "0"}], ",", 
       RowBox[{
        RowBox[{"Uz1", "[", 
         RowBox[{"H", "[", "Z", "]"}], "]"}], "==", "0"}]}], "}"}], ",", 
     RowBox[{"Uz1", "[", "Y", "]"}], ",", "Y"}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Uz1", "[", 
     RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     FractionBox[
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["Y", "2"], "-", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "Z", "]"}], "5"], " ", 
          RowBox[{"Pgrad1", "[", "Z", "]"}]}], "+", 
         RowBox[{"18", " ", "\[Beta]t", " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "5"]}]], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "The", " ", "axial", " ", "velocity", " ", "Uz1", " ", "at", " ", "O", 
    RowBox[{"(", "De", ")"}], " ", "is", " ", "identically", " ", "zero"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"H", "[", "Z", "]"}]], 
      RowBox[{
       RowBox[{"Uz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}], "==", "0"}], ",", 
    RowBox[{"Pgrad1", "[", "Z", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pgrad1", "[", "Z_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"18", " ", "\[Beta]t", " ", 
       RowBox[{
        SuperscriptBox["H", "\[Prime]",
         MultilineFunction->None], "[", "Z", "]"}]}], 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "5"]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Uy1", "[", 
     RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "Y"], 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "Z"], " ", 
         RowBox[{"Uz1", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], 
        RowBox[{"\[DifferentialD]", "Y"}]}]}]}], "]"}]}], ";"}], "  ", 
  RowBox[{"(*", 
   RowBox[{
   "The", " ", "transverse", " ", "velocity", " ", "Uy1", " ", "at", " ", "O", 
    RowBox[{"(", "De", ")"}], " ", "is", " ", "identically", " ", "zero"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
    RowBox[{
     RowBox[{"Pgrad1", "[", "Z", "]"}], 
     RowBox[{"\[DifferentialD]", "Z"}]}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Uz1", "[", 
    RowBox[{"Y", ",", "Z"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Uy1", "[", 
     RowBox[{"Y", ",", "Z"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Help1", " ", "is", " ", "an", " ", "auxiliary", "  ", "function", " ", 
    "to", " ", "calculate", " ", "the", " ", "prerssure", " ", "gradient", 
    " ", "field", " ", "at", " ", "O", 
    RowBox[{"(", "De", ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Help1", "[", "Z_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"\[Integral]", 
     RowBox[{
      RowBox[{"Pgrad1", "[", "Z", "]"}], 
      RowBox[{"\[DifferentialD]", "Z"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dP1", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Help1", "[", "0", "]"}], "-", 
      RowBox[{"Help1", "[", "1", "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Final", " ", "expression", " ", "for", " ", "the", " ", "pressure", " ", 
    "drop", " ", "at", " ", "O", 
    RowBox[{"(", "De", ")"}], " ", "after", " ", "simplifications"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dP1Final", "=", 
    RowBox[{
     FractionBox["9", "2"], " ", "\[Beta]t", " ", 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"H", "[", "0", "]"}], "4"]], "-", 
       FractionBox["1", 
        SuperscriptBox[
         RowBox[{"H", "[", "1", "]"}], "4"]]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "To", " ", "check", " ", "the", " ", "consistency", " ", "of", " ", "our", 
    " ", "solution", " ", "and", " ", "final", " ", "expression", " ", "at", 
    " ", "O", 
    RowBox[{"(", "De", ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"dP1", "-", "dP1Final"}], "]"}]}], "Input",
 CellChangeTimes->{{3.9015069844996276`*^9, 3.9015071894312325`*^9}, {
   3.901507235128808*^9, 3.9015073770785666`*^9}, {3.9015074087441254`*^9, 
   3.90150749338431*^9}, {3.901507550939759*^9, 3.90150755122796*^9}, {
   3.901507609245981*^9, 3.901507611475498*^9}, {3.9015076683340015`*^9, 
   3.901507720282916*^9}, {3.901507856643358*^9, 3.90150797330723*^9}, {
   3.9015080749172435`*^9, 3.9015081212694426`*^9}, {3.9015081698784733`*^9, 
   3.9015082189131403`*^9}, {3.9015082598224025`*^9, 
   3.9015084088238525`*^9}, {3.9015100799192667`*^9, 3.901510205037289*^9}, {
   3.9015104085134373`*^9, 3.901510441372952*^9}, {3.90151052001513*^9, 
   3.9015106794711933`*^9}, {3.9015107137761784`*^9, 
   3.9015107408262043`*^9}, {3.9015107787155924`*^9, 
   3.9015109052443533`*^9}, {3.9015109676351824`*^9, 
   3.9015109683580093`*^9}, {3.9015110299907217`*^9, 3.901511062487323*^9}, 
   3.9015112806768227`*^9, {3.9042718155048556`*^9, 3.9042718543435626`*^9}, {
   3.9042718948239813`*^9, 3.9042719215146646`*^9}, {3.904271956307263*^9, 
   3.904271992826277*^9}, 3.904272097844346*^9, {3.9042721319699965`*^9, 
   3.9042721346994286`*^9}, {3.904272672197963*^9, 3.904272692265715*^9}, 
   3.9042729447208614`*^9, {3.904273511469351*^9, 3.904273514930621*^9}, {
   3.9137017561112123`*^9, 3.913701782104248*^9}, {3.9137018318916607`*^9, 
   3.9137018344628515`*^9}, {3.9230455655939803`*^9, 
   3.9230455750001593`*^9}, {3.9232722082183647`*^9, 
   3.9232722206236715`*^9}, {3.9232723238896723`*^9, 
   3.9232725052977076`*^9}, {3.92327309655373*^9, 3.9232732065272303`*^9}, {
   3.9232732697113557`*^9, 3.9232734062166204`*^9}, {3.923273686574356*^9, 
   3.9232737342139173`*^9}, {3.923273793527833*^9, 3.9232738520177794`*^9}, {
   3.92327390449881*^9, 3.923274010918131*^9}, {3.9232740438768473`*^9, 
   3.923274079402313*^9}, {3.923274125179259*^9, 3.92327416877277*^9}, {
   3.9232742100301*^9, 3.9232743105460663`*^9}, {3.923274345904222*^9, 
   3.9232743767238097`*^9}, {3.923274448752076*^9, 3.923274542814245*^9}, {
   3.9232746337769403`*^9, 3.9232746625808473`*^9}, {3.923274743906844*^9, 
   3.9232747694028196`*^9}, {3.923276481279417*^9, 3.92327655863181*^9}, {
   3.923366744800091*^9, 3.923366831852419*^9}, {3.9234750216015368`*^9, 
   3.9234750374253893`*^9}, {3.9234750878983946`*^9, 3.923475107761667*^9}, {
   3.9234752517277074`*^9, 3.9234752575548954`*^9}, {3.9235358074816933`*^9, 
   3.923535868966226*^9}, {3.9235359049635763`*^9, 3.92353590770285*^9}, {
   3.9235604272684*^9, 3.9235604334333944`*^9}, {3.923619212080826*^9, 
   3.923619241063779*^9}, {3.9236234431089215`*^9, 3.9236234465700755`*^9}, {
   3.9236234797862005`*^9, 3.9236235225753775`*^9}, {3.9236239675396132`*^9, 
   3.9236240075970736`*^9}, {3.9236242618921556`*^9, 
   3.9236242712058306`*^9}, {3.923624381857373*^9, 3.9236244454899917`*^9}, {
   3.923624480098188*^9, 3.923624516172162*^9}, {3.9236290614483614`*^9, 
   3.9236290922332215`*^9}, {3.9236520892315474`*^9, 
   3.9236520965274253`*^9}, {3.923876185876361*^9, 3.923876205695904*^9}, {
   3.9239020780220194`*^9, 3.9239020835116043`*^9}, {3.9239022903290386`*^9, 
   3.92390230405847*^9}, {3.923902337372495*^9, 3.9239024339043765`*^9}, {
   3.9239027178257504`*^9, 3.923902735905896*^9}, {3.924516851260934*^9, 
   3.9245168631821117`*^9}, {3.92451705820903*^9, 3.924517059132654*^9}, {
   3.924517312025402*^9, 3.9245173253054805`*^9}, {3.924569656153425*^9, 
   3.9245697279115343`*^9}, 3.92456976439645*^9, 
   3.9306506393737855`*^9},ExpressionUUID->"3ff51b4c-7960-4473-b3fb-\
911becd55d1d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.9232765359382715`*^9, 3.9232765662373333`*^9, 3.9233668006444974`*^9, 
   3.923366840026979*^9, 3.923475050877104*^9, {3.9234751268916593`*^9, 
   3.9234751461609783`*^9}, 3.9235358805748377`*^9, 3.9235359456216536`*^9, 
   3.923560460034233*^9, {3.9236192305497046`*^9, 3.923619253827179*^9}, 
   3.9236244026367483`*^9, 3.9236244589675393`*^9, {3.923624507636918*^9, 
   3.9236245337563677`*^9}, 3.923876216736723*^9, 3.923902444091318*^9},
 CellLabel->"Out[25]=",ExpressionUUID->"83419dae-57e8-4a64-becd-bb10cfb92b7b"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Second-order solution FENE-CR", "Title",
 CellChangeTimes->{{3.901511292677*^9, 3.901511312945997*^9}, 
   3.9015113479437513`*^9, {3.914129408561033*^9, 
   3.914129409553769*^9}},ExpressionUUID->"27630eb1-f5ef-4202-a0c4-\
c30c85a00093"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Uz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["Y", "2"], "-", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "3"]}]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"3", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["Y", "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "Z", "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "4"]}]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     SubscriptBox["\[PartialD]", "Y"], " ", 
     RowBox[{"Uz0", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"2", "*", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"2", "*", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
     RowBox[{"Ayz1", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Azz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Azz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Ayy3", "[", 
     RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Uz0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Ayy2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Ayy2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uy0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayy1", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         RowBox[{"Azz2", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], ";"}],
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Auxiliary", " ", "function", " ", "used", " ", "to", " ", "calculate", 
    " ", "the", " ", "velocity", " ", "and", " ", "pressure", " ", "at", " ", 
    "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "2"], ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AUXzz3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Azz3", "[", 
     RowBox[{"Y", ",", "Z"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"AUXyz3", "[", 
     RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Ayz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayz1", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         RowBox[{"Azz2", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Pgrad2", "[", "Z", "]"}], "==", 
        RowBox[{
         RowBox[{
          RowBox[{"Uz2", "''"}], "[", "Y", "]"}], "+", 
         RowBox[{"\[Beta]t", "*", 
          RowBox[{
           SubscriptBox["\[PartialD]", "Z"], " ", 
           RowBox[{"AUXzz3", "[", 
            RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
         RowBox[{"\[Beta]t", "*", 
          RowBox[{
           SubscriptBox["\[PartialD]", "Y"], " ", 
           RowBox[{"AUXyz3", "[", 
            RowBox[{"Y", ",", "Z"}], "]"}]}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Uz2", "'"}], "[", "0", "]"}], "==", "0"}], ",", 
       RowBox[{
        RowBox[{"Uz2", "[", 
         RowBox[{"H", "[", "Z", "]"}], "]"}], "==", "0"}]}], "}"}], ",", 
     RowBox[{"Uz2", "[", "Y", "]"}], ",", "Y"}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "Y"}], "+", 
        RowBox[{"H", "[", "Z", "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Y", "+", 
        RowBox[{"H", "[", "Z", "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "10"}], " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "10"], " ", 
         RowBox[{"Pgrad2", "[", "Z", "]"}]}], "+", 
        RowBox[{"270", " ", "\[Beta]t", " ", 
         RowBox[{"H", "[", "Z", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["Y", "2"], "-", 
           RowBox[{"5", " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "Z", "]"}], "2"]}]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}], "2"]}], "+", 
        RowBox[{"27", " ", "\[Beta]t", " ", 
         RowBox[{"(", 
          RowBox[{
           SuperscriptBox["Y", "4"], "-", 
           RowBox[{"4", " ", 
            SuperscriptBox["Y", "2"], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "Z", "]"}], "2"]}], "+", 
           RowBox[{"11", " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "Z", "]"}], "4"]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], 
     RowBox[{"20", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "10"]}]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"H", "[", "Z", "]"}]], 
      RowBox[{
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}], "==", "0"}], ",", 
    RowBox[{"Pgrad2", "[", "Z", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pgrad2", "[", "Z_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"324", " ", "\[Beta]t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"14", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], "2"]}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"H", "[", "Z", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], 
      RowBox[{"35", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "7"]}]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "Y"], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Uz2", "[", 
    RowBox[{"Y", ",", "Z"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Uy2", "[", 
    RowBox[{"Y", ",", "Z"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dP2", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Pgrad2", "[", "Z", "]"}]}], 
       RowBox[{"\[DifferentialD]", "Z"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Final", " ", "expression", " ", "for", " ", "the", " ", "pressure", " ", 
    "drop", " ", "at", " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "2"], ")"}], " ", "after", " ", "simplifications"}],
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dP2Final", "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], 
     RowBox[{
      FractionBox[
       RowBox[{"324", " ", "\[Beta]t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"14", " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], "-", 
          RowBox[{"3", " ", 
           RowBox[{"H", "[", "Z", "]"}], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], 
       RowBox[{"35", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "7"]}]], 
      RowBox[{"\[DifferentialD]", "Z"}]}]}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "To", " ", "check", " ", "the", " ", "consistency", " ", "of", " ", "our", 
    " ", "solution", " ", "and", " ", "final", " ", "expression", " ", "at", 
    " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "2"], ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"dP2", "-", "dP2Final"}], "]"}]}], "Input",
 CellChangeTimes->{{3.901510945441201*^9, 3.901510945441201*^9}, {
   3.9015113503763995`*^9, 3.9015113536076508`*^9}, {3.9015119127468853`*^9, 
   3.9015122197136946`*^9}, {3.901512253468708*^9, 3.901512254908781*^9}, {
   3.901512310222643*^9, 3.901512445116253*^9}, {3.901512522045636*^9, 
   3.901512526420083*^9}, {3.901512564896379*^9, 3.9015125909925504`*^9}, {
   3.901512686635844*^9, 3.901512707765856*^9}, {3.9015127399914665`*^9, 
   3.9015127640283065`*^9}, {3.9015130053365293`*^9, 3.9015130148612304`*^9}, 
   3.901513696098322*^9, {3.901521630188554*^9, 3.901521694570518*^9}, {
   3.9015218962631245`*^9, 3.901522002685768*^9}, 3.901522052039119*^9, {
   3.9015220911328964`*^9, 3.901522124819446*^9}, {3.901523292598526*^9, 
   3.901523298466316*^9}, {3.901523453698059*^9, 3.9015234742316236`*^9}, {
   3.901523513981183*^9, 3.901523522982044*^9}, {3.9015245369775624`*^9, 
   3.9015245647469254`*^9}, {3.9015245986009817`*^9, 
   3.9015245993698792`*^9}, {3.901766666222017*^9, 3.9017666671143694`*^9}, {
   3.9017701613302956`*^9, 3.9017701622271357`*^9}, {3.9017702090581007`*^9, 
   3.9017702161727333`*^9}, {3.9017702665257487`*^9, 3.901770307119543*^9}, {
   3.901770390854116*^9, 3.9017703970268717`*^9}, {3.9017752886198225`*^9, 
   3.901775302279011*^9}, {3.9017775401766043`*^9, 3.9017775521254907`*^9}, {
   3.901777661199735*^9, 3.901777672095975*^9}, {3.901778021914184*^9, 
   3.9017780235282116`*^9}, {3.9017918958982935`*^9, 3.901791901104701*^9}, {
   3.9017922173021803`*^9, 3.9017922537056546`*^9}, {3.901849288321698*^9, 
   3.9018493070695877`*^9}, {3.9018494241158648`*^9, 3.901849499540579*^9}, 
   3.901858582815015*^9, {3.9019337659373064`*^9, 3.901933796705308*^9}, {
   3.902137150417487*^9, 3.9021371533117867`*^9}, {3.9042721715484505`*^9, 
   3.904272297668745*^9}, {3.904272604924465*^9, 3.9042726493790665`*^9}, {
   3.904272739557457*^9, 3.9042727464069157`*^9}, {3.9042729151582537`*^9, 
   3.9042729155199428`*^9}, {3.9042730798983407`*^9, 3.904273104449671*^9}, {
   3.9137018690589066`*^9, 3.913701887056574*^9}, 3.9137019224510145`*^9, {
   3.923274682481836*^9, 3.92327471211022*^9}, {3.9232758339450054`*^9, 
   3.9232761989520507`*^9}, {3.923276243699006*^9, 3.9232762579032817`*^9}, {
   3.923276582088031*^9, 3.9232766626932364`*^9}, {3.923276953702304*^9, 
   3.923276958741517*^9}, {3.923276995596629*^9, 3.923277031887437*^9}, 
   3.9232772482002525`*^9, {3.9232773647620797`*^9, 3.9232773698235855`*^9}, 
   3.923279054621909*^9, {3.9232895400267897`*^9, 3.9232895626603265`*^9}, {
   3.9233668501227164`*^9, 3.9233669425311403`*^9}, {3.92344512862639*^9, 
   3.9234452108828115`*^9}, {3.9234468473264475`*^9, 
   3.9234468590162635`*^9}, {3.923535955670738*^9, 3.9235360314552765`*^9}, {
   3.923554817590249*^9, 3.9235548304862776`*^9}, {3.923555917785366*^9, 
   3.923555919722785*^9}, {3.9235604727783504`*^9, 3.9235604786315637`*^9}, {
   3.923619265810422*^9, 3.923619298171824*^9}, {3.9236240146305466`*^9, 
   3.9236240188758817`*^9}, 3.9236245393760767`*^9, {3.923643031977522*^9, 
   3.923643032798225*^9}, {3.9238761422313094`*^9, 3.923876167771246*^9}, {
   3.9239020934340887`*^9, 3.923902111189011*^9}, {3.9239024575020685`*^9, 
   3.923902530010006*^9}, {3.9239027178414583`*^9, 3.923902735967127*^9}, 
   3.9245170630692883`*^9, {3.924517331774024*^9, 3.924517335364126*^9}, 
   3.930650656218875*^9},ExpressionUUID->"09ea0d15-b582-472e-a2dd-\
7c440edbcc14"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{{3.923289555724908*^9, 3.923289569495632*^9}, 
   3.9233669293711023`*^9, {3.9234451940971327`*^9, 3.9234452190035872`*^9}, 
   3.9234468837414875`*^9, 3.9235360391308174`*^9, 3.923560523162052*^9, {
   3.9236192818179893`*^9, 3.9236193064297113`*^9}, 3.9236245491887956`*^9, 
   3.9238761780131626`*^9, 3.9239025413462753`*^9},
 CellLabel->"Out[28]=",ExpressionUUID->"358428bb-802d-4e0b-a447-034581b7698d"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Third-order solution FENE-CR", "Title",
 CellChangeTimes->{{3.901933869147939*^9, 3.901933913387188*^9}, {
  3.914129402761792*^9, 
  3.9141294036092887`*^9}},ExpressionUUID->"112f3e4a-2b79-4731-b2bc-\
8602d7c1939e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Uz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["Y", "2"], "-", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "3"]}]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"3", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["Y", "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "Z", "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "4"]}]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     SubscriptBox["\[PartialD]", "Y"], " ", 
     RowBox[{"Uz0", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"2", "*", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"2", "*", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
     RowBox[{"Ayz1", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"27", " ", "\[Beta]t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "Y"}], "+", 
        RowBox[{"H", "[", "Z", "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Y", "+", 
        RowBox[{"H", "[", "Z", "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "14"}], " ", 
         RowBox[{"H", "[", "Z", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "5"}], " ", 
            SuperscriptBox["Y", "2"]}], "+", 
           SuperscriptBox[
            RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"7", " ", 
            SuperscriptBox["Y", "4"]}], "-", 
           RowBox[{"28", " ", 
            SuperscriptBox["Y", "2"], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "Z", "]"}], "2"]}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "Z", "]"}], "4"]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], 
     RowBox[{"140", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "10"]}]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "Y"], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Azz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Azz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayy1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz4", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Azz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Azz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "2"], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz4", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Ayy4", "[", 
     RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Uz0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Ayy3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Ayy1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Ayy3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"Uy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Ayy1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uy0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uy2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayy3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayy2", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         RowBox[{"Azz2", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "-", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayy1", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         RowBox[{"Azz3", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], ";"}],
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Auxiliary", " ", "functions", " ", "used", " ", "to", " ", "calculate", 
    " ", "the", " ", "velocity", " ", "at", " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "3"], ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AUXzz4", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Azz4", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}], "+", 
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "2"], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AUXyz4", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Ayz4", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}], "-", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "+", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Pgrad3", "[", "Z", "]"}], "==", 
        RowBox[{
         RowBox[{
          RowBox[{"Uz3", "''"}], "[", "Y", "]"}], "+", 
         RowBox[{"\[Beta]t", "*", 
          RowBox[{
           SubscriptBox["\[PartialD]", "Z"], " ", 
           RowBox[{"AUXzz4", "[", 
            RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
         RowBox[{"\[Beta]t", "*", 
          RowBox[{
           SubscriptBox["\[PartialD]", "Y"], " ", 
           RowBox[{"AUXyz4", "[", 
            RowBox[{"Y", ",", "Z"}], "]"}]}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Uz3", "'"}], "[", "0", "]"}], "==", "0"}], ",", 
       RowBox[{
        RowBox[{"Uz3", "[", 
         RowBox[{"H", "[", "Z", "]"}], "]"}], "==", "0"}]}], "}"}], ",", 
     RowBox[{"Uz3", "[", "Y", "]"}], ",", "Y"}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"560", " ", "Leps2", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "14"]}]], 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["Y", "2"], "-", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"280", " ", "Leps2", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "14"], " ", 
        RowBox[{"Pgrad3", "[", "Z", "]"}]}], "-", 
       RowBox[{"2835", " ", "Leps2", " ", 
        SuperscriptBox["Y", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", "\[Beta]t", " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"17577", " ", "Leps2", " ", 
        SuperscriptBox["Y", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "-", 
       RowBox[{"44793", " ", "Leps2", " ", 
        SuperscriptBox["Y", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"567", " ", "Leps2", " ", "\[Beta]t", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "362"}], "+", 
          RowBox[{"53", " ", "\[Beta]t"}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "6"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"81", " ", "Leps2", " ", 
        RowBox[{"(", 
         RowBox[{"186", "-", 
          RowBox[{"29", " ", "\[Beta]t"}]}], ")"}], " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "7"], " ", 
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"81", " ", 
        SuperscriptBox["Y", "2"], " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"896", " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"Leps2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["H", "\[Prime]",
                 MultilineFunction->None], "[", "Z", "]"}], "2"]}]}], ")"}]}],
           "-", 
          RowBox[{"23", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"81", " ", 
        SuperscriptBox["Y", "4"], " ", "\[Beta]t", " ", 
        RowBox[{"H", "[", "Z", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"224", " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}]}], "-", 
          RowBox[{"224", " ", "Leps2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "3"]}], "+", 
          RowBox[{"5", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"81", " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"224", " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "4"}], "+", 
             RowBox[{"Leps2", " ", 
              RowBox[{"(", 
               RowBox[{"22", "-", 
                RowBox[{"3", " ", "\[Beta]t"}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["H", "\[Prime]",
                 MultilineFunction->None], "[", "Z", "]"}], "2"]}]}], ")"}]}],
           "+", 
          RowBox[{"47", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}]}], 
      ")"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"H", "[", "Z", "]"}]], 
      RowBox[{
       RowBox[{"Uz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}], "==", "0"}], ",", 
    RowBox[{"Pgrad3", "[", "Z", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pgrad3", "[", "Z_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"108", " ", "\[Beta]t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"99", " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}]}], "-", 
        RowBox[{"432", " ", "Leps2", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}], "3"]}], "+", 
        RowBox[{"48", " ", "Leps2", " ", "\[Beta]t", " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}], "3"]}], "+", 
        RowBox[{"220", " ", "Leps2", " ", 
         RowBox[{"H", "[", "Z", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}]}], "-", 
        RowBox[{"26", " ", "Leps2", " ", "\[Beta]t", " ", 
         RowBox[{"H", "[", "Z", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}]}], "-", 
        RowBox[{"16", " ", "Leps2", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["H", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "Z", "]"}]}], "+", 
        RowBox[{"2", " ", "Leps2", " ", "\[Beta]t", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["H", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], 
     RowBox[{"35", " ", "Leps2", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "9"]}]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "Y"], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uz3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Uz3", "[", 
    RowBox[{"Y", ",", "Z"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Uy3", "[", 
     RowBox[{"Y", ",", "Z"}], "]"}], "]"}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Help3", " ", "is", " ", "an", " ", "auxiliary", " ", "function", " ", 
    "to", " ", "calculate", " ", "the", " ", "prerssure", " ", "gradient", 
    " ", "field", " ", "at", " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "3"], ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Help3", "[", "Z_", "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"\[Integral]", 
      RowBox[{
       RowBox[{"Pgrad3", "[", "Z", "]"}], 
       RowBox[{"\[DifferentialD]", "Z"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Calculation", " ", "of", " ", "the", " ", "prerssure", " ", "drop", " ", 
    "at", " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "3"], ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dP3", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Help3", "[", "0", "]"}], "-", 
      RowBox[{"Help3", "[", "1", "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Final", " ", "expression", " ", "for", " ", "the", " ", "pressure", " ", 
    "drop", " ", "at", " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "3"], ")"}], " ", "after", " ", "simplifications"}],
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dP3Final", "=", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2673", " ", "\[Beta]t", " "}], 
        RowBox[{"70", " ", "Leps2"}]]}], 
      RowBox[{"(", 
       RowBox[{
        FractionBox["1", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "0", "]"}], "8"], " "}]], "-", 
        FractionBox["1", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "1", "]"}], "8"], " "}]]}], ")"}]}], "+", 
     RowBox[{
      FractionBox[
       RowBox[{"648", "  ", "\[Beta]t", " ", 
        RowBox[{"(", 
         RowBox[{"9", "-", "\[Beta]t"}], ")"}]}], 
       RowBox[{"35", " "}]], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "0", "]"}], "2"], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "0", "]"}], "8"], " "}]], "-", 
        FractionBox[
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "1", "]"}], "2"], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "1", "]"}], "8"], " "}]]}], ")"}]}], "-", 
     RowBox[{
      FractionBox[
       RowBox[{"216", " ", "\[Beta]t", " ", 
        RowBox[{"(", 
         RowBox[{"8", "-", "\[Beta]t"}], ")"}]}], "35"], 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "0", "]"}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "0", "]"}], "7"], " "}]], "-", 
        FractionBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "1", "]"}], 
         RowBox[{
          SuperscriptBox[
           RowBox[{"H", "[", "1", "]"}], "7"], " "}]]}], ")"}]}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "To", " ", "check", " ", "the", " ", "consistency", " ", "of", " ", "our", 
    " ", "solution", " ", "and", " ", "final", " ", "expression", " ", "at", 
    " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "3"], ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"dP3", "-", "dP3Final"}], "]"}]}], "Input",
 CellChangeTimes->{{3.9019339695504723`*^9, 3.901934073546769*^9}, {
   3.9019341296658964`*^9, 3.9019341315104876`*^9}, {3.901934173976559*^9, 
   3.9019341774638696`*^9}, {3.9019342337551155`*^9, 3.901934293968156*^9}, {
   3.901934418580635*^9, 3.901934546369404*^9}, {3.9019347045876207`*^9, 
   3.901934738183874*^9}, {3.9019348114450197`*^9, 3.901934831220656*^9}, {
   3.9019348618576546`*^9, 3.901934924863061*^9}, 3.9019349836171474`*^9, {
   3.901935051937524*^9, 3.901935089532654*^9}, {3.901935145131322*^9, 
   3.901935159256036*^9}, {3.9019351996966105`*^9, 3.9019352006237926`*^9}, {
   3.901935259804118*^9, 3.901935311436708*^9}, {3.901935371930478*^9, 
   3.9019354012393165`*^9}, {3.9019354439838533`*^9, 
   3.9019354637105055`*^9}, {3.901935494492406*^9, 3.9019354956681366`*^9}, {
   3.901935575652751*^9, 3.9019355762340684`*^9}, {3.901936053730321*^9, 
   3.9019364228409452`*^9}, {3.9019364549312005`*^9, 3.901936478153325*^9}, {
   3.901936548552697*^9, 3.9019365494198637`*^9}, {3.9019394775753164`*^9, 
   3.9019394964011374`*^9}, {3.901939682177348*^9, 3.9019396824682016`*^9}, {
   3.901939808127134*^9, 3.901939826628729*^9}, {3.9021372506945534`*^9, 
   3.9021372521570225`*^9}, {3.9021373610578427`*^9, 
   3.9021373666520276`*^9}, {3.9021374108014193`*^9, 
   3.9021374293970394`*^9}, {3.902198787817688*^9, 3.902198788747678*^9}, {
   3.90219884472174*^9, 3.9021988617571845`*^9}, {3.902199033440485*^9, 
   3.9021990337201166`*^9}, {3.9021993786515875`*^9, 
   3.9021993792413397`*^9}, {3.902199884549757*^9, 3.9021998885868716`*^9}, 
   3.902199925876507*^9, {3.902200108007263*^9, 3.9022001185084176`*^9}, {
   3.9022001595826397`*^9, 3.9022001618109465`*^9}, {3.9022002246523323`*^9, 
   3.902200245712984*^9}, {3.9022004503524513`*^9, 3.9022004573872404`*^9}, {
   3.9022004970742426`*^9, 3.9022005098676805`*^9}, {3.9022005504760504`*^9, 
   3.902200561156931*^9}, 3.902200599631915*^9, 3.902200640692909*^9, {
   3.9022219438755655`*^9, 3.9022219504209614`*^9}, {3.902222020315036*^9, 
   3.902222031728281*^9}, {3.9022806520791407`*^9, 3.902280652374097*^9}, {
   3.9022806924897394`*^9, 3.9022807270176554`*^9}, {3.9042730107346554`*^9, 
   3.904273016391139*^9}, {3.904273142460678*^9, 3.904273256048848*^9}, {
   3.913700690646063*^9, 3.913700788740452*^9}, {3.9137008298961897`*^9, 
   3.9137009560145893`*^9}, {3.9137010509240437`*^9, 
   3.9137010747281265`*^9}, {3.913701132999483*^9, 3.913701133746911*^9}, {
   3.913701618742601*^9, 3.9137016194407787`*^9}, 3.9137058524028177`*^9, {
   3.923277309900401*^9, 3.9232773361390142`*^9}, {3.923277405746669*^9, 
   3.9232774650745516`*^9}, {3.9232778922957263`*^9, 3.923278203136158*^9}, {
   3.9232783275384803`*^9, 3.923278551060543*^9}, {3.9232786120164566`*^9, 
   3.9232786221513524`*^9}, {3.923278665138317*^9, 3.92327902710625*^9}, {
   3.923279061617488*^9, 3.9232791198593693`*^9}, {3.9232792124998074`*^9, 
   3.923279292000883*^9}, {3.923279409574502*^9, 3.923279417040868*^9}, {
   3.923289579430729*^9, 3.923289583695232*^9}, {3.9233669486871214`*^9, 
   3.9233672011930304`*^9}, {3.92344522824106*^9, 3.923445281721433*^9}, {
   3.9234453321694775`*^9, 3.923445385520926*^9}, {3.92344583543919*^9, 
   3.923445864609728*^9}, {3.923446888062891*^9, 3.9234470309424505`*^9}, {
   3.923536062598566*^9, 3.9235361604367113`*^9}, {3.9235362317742147`*^9, 
   3.9235362423757243`*^9}, {3.923536288844*^9, 3.923536293453311*^9}, {
   3.923536411490594*^9, 3.923536412389259*^9}, {3.923554880965375*^9, 
   3.923555003831674*^9}, {3.923555144568404*^9, 3.9235551632070427`*^9}, {
   3.923555193476268*^9, 3.9235553836996756`*^9}, 3.923555429381212*^9, {
   3.9235554669709444`*^9, 3.9235554862667837`*^9}, {3.92355553125093*^9, 
   3.923555595913291*^9}, {3.923555637452201*^9, 3.9235557032297664`*^9}, {
   3.9235557524439673`*^9, 3.923555760121911*^9}, {3.9235558116988187`*^9, 
   3.9235558354514046`*^9}, {3.923555923411627*^9, 3.923555930750718*^9}, {
   3.9236188842308187`*^9, 3.9236189468919773`*^9}, {3.923619315988171*^9, 
   3.9236193279730453`*^9}, {3.923619358491618*^9, 3.923619365838023*^9}, {
   3.923620518816146*^9, 3.923620564268241*^9}, {3.92362403119433*^9, 
   3.9236240388170586`*^9}, {3.9236245650946703`*^9, 3.923624580171776*^9}, {
   3.923628971400028*^9, 3.923628982432459*^9}, {3.923629115886261*^9, 
   3.923629146064142*^9}, {3.923629225967703*^9, 3.9236292278608155`*^9}, {
   3.9236419952536488`*^9, 3.92364199566686*^9}, {3.923643025130384*^9, 
   3.9236430255762825`*^9}, {3.923902548716504*^9, 3.923902649744872*^9}, {
   3.9239027178890724`*^9, 3.9239027360876875`*^9}, 3.9245170694223223`*^9, {
   3.924517343690448*^9, 3.924517354657281*^9}, {3.924569799263996*^9, 
   3.924569814975994*^9}, {3.930650662421116*^9, 
   3.9306506663974257`*^9}},ExpressionUUID->"5b387132-769d-40ae-8e7b-\
bbbe9affae5d"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.9235554428865623`*^9, 3.9236193327863197`*^9, 
  3.923619378537032*^9, 3.9236245951183567`*^9, 3.923902763790738*^9, 
  3.923911542297213*^9},
 CellLabel->"Out[34]=",ExpressionUUID->"754f9dde-9b31-4252-9e21-2b16763c56dc"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fourth-order solution FENE-CR", "Title",
 CellChangeTimes->{{3.9137012402110615`*^9, 3.913701252207883*^9}, {
  3.913701633272423*^9, 3.9137016501429048`*^9}, {3.9137079036699047`*^9, 
  3.913707905214615*^9}, {3.9141293976033163`*^9, 
  3.9141293982897367`*^9}},ExpressionUUID->"bfd22989-1cfe-4eca-800d-\
489d4620359f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Uzb", "[", 
     RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["Y", "2"], "-", 
          SuperscriptBox[
           RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}]}], 
       RowBox[{"2", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "3"]}]]}], "]"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "Expression", " ", "for", " ", "the", " ", "velocity", " ", "of", " ", 
     "the", " ", "Newtonian", " ", 
     RowBox[{"fluid", ".", " ", "We"}], " ", "will", " ", "use", " ", "this", 
     " ", "for", " ", "calculating", " ", "the", " ", "fourth"}], "-", 
    RowBox[{
    "order", " ", "pressure", " ", "drop", " ", "from", " ", "the", " ", 
     "integral", " ", "formulation", " ", "given", " ", "in", " ", 
     RowBox[{"Eq", ".", " ", 
      RowBox[{"(", 
       RowBox[{"B", " ", "13"}], ")"}]}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     FractionBox[
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{
         SuperscriptBox["Y", "2"], "-", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}]}], 
      RowBox[{"2", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "3"]}]]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"3", " ", "Y", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["Y", "2"]}], "+", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
      RowBox[{
       SuperscriptBox["H", "\[Prime]",
        MultilineFunction->None], "[", "Z", "]"}]}], 
     RowBox[{"2", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "4"]}]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy0", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "1"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     SubscriptBox["\[PartialD]", "Y"], " ", 
     RowBox[{"Uz0", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"2", "*", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy1", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", "0"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"2", "*", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
     RowBox[{"Ayz1", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"27", " ", "\[Beta]t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "Y"}], "+", 
        RowBox[{"H", "[", "Z", "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"Y", "+", 
        RowBox[{"H", "[", "Z", "]"}]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "14"}], " ", 
         RowBox[{"H", "[", "Z", "]"}], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "5"}], " ", 
            SuperscriptBox["Y", "2"]}], "+", 
           SuperscriptBox[
            RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}], "2"]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"7", " ", 
            SuperscriptBox["Y", "4"]}], "-", 
           RowBox[{"28", " ", 
            SuperscriptBox["Y", "2"], " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "Z", "]"}], "2"]}], "+", 
           RowBox[{"5", " ", 
            SuperscriptBox[
             RowBox[{"H", "[", "Z", "]"}], "4"]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], 
     RowBox[{"140", " ", 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "10"]}]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy2", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "Y"], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Azz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Azz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayy1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"560", " ", "Leps2", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "14"]}]], "27", " ", "\[Beta]t", " ", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["Y", "2"], "-", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "105"}], " ", "Leps2", " ", 
        SuperscriptBox["Y", "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"651", " ", "Leps2", " ", 
        SuperscriptBox["Y", "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "-", 
       RowBox[{"1659", " ", "Leps2", " ", 
        SuperscriptBox["Y", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "4"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"281", " ", "Leps2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "6"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "-", 
       RowBox[{"23", " ", "Leps2", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "7"], " ", 
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["Y", "2"], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"896", " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", 
             RowBox[{"Leps2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["H", "\[Prime]",
                 MultilineFunction->None], "[", "Z", "]"}], "2"]}]}], ")"}]}],
           "-", 
          RowBox[{"23", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox["Y", "4"], " ", 
        RowBox[{"H", "[", "Z", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"224", " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}]}], "-", 
          RowBox[{"224", " ", "Leps2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "3"]}], "+", 
          RowBox[{"5", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"3", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"160", " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}]}], "-", 
          RowBox[{"160", " ", "Leps2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "3"]}], "+", 
          RowBox[{"47", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "2"}], "+", "\[Beta]t"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}]}], 
      ")"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uy3", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"-", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "Y"], 
      RowBox[{
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uz3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz4", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Azz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Azz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       SuperscriptBox[
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "2"], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz4", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayy4", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayy3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayy3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uy3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayy2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayy1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Azz5", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Azz4", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Azz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Azz4", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Azz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz4", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz4", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{"2", "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayz1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"2", "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Ayz5", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz4", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uz3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy0", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz4", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
     RowBox[{
      RowBox[{"Uy3", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "*", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz4", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Z"], " ", 
       RowBox[{"Uy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Azz2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy4", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy2", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
      RowBox[{"Ayy1", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
     RowBox[{
      SubscriptBox["\[PartialD]", "Y"], " ", 
      RowBox[{"Uz4", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}]}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        SuperscriptBox[
         RowBox[{"Azz2", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "2"]}], 
       SuperscriptBox["Leps2", "2"]], ")"}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "-", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"Ayz1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz4", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Ayy5", "[", 
     RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"Uz0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Ayy4", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"Uz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Ayy2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"Uz3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Ayy1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"Uy0", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Ayy4", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"Uy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Ayy2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{
       RowBox[{"Uy3", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Ayy1", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uy0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayz4", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uy2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayz2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Z"], " ", 
        RowBox[{"Uy3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayz1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy0", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayy4", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayy2", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "*", 
       RowBox[{"Ayy1", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"2", "*", 
       RowBox[{
        SubscriptBox["\[PartialD]", "Y"], " ", 
        RowBox[{"Uy4", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}]}], "-", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayy1", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         SuperscriptBox[
          RowBox[{"Azz2", "[", 
           RowBox[{"Y", ",", "Z"}], "]"}], "2"]}], 
        SuperscriptBox["Leps2", "2"]], ")"}], "-", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayy3", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         RowBox[{"Azz2", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "-", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayy2", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         RowBox[{"Azz3", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "-", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayy1", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         RowBox[{"Azz4", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], ";"}],
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Auxiliary", " ", "function", " ", "used", " ", "to", " ", "calculate", 
    " ", "the", " ", "velocity", " ", "at", " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "4"], ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AUXzz5", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"Azz5", "[", 
      RowBox[{"Y", ",", "Z"}], "]"}], "+", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{"2", "*", 
        RowBox[{"Azz2", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}], "*", 
        RowBox[{"Azz3", "[", 
         RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"AUXyz5", "[", 
     RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{"Ayz5", "[", 
       RowBox[{"Y", ",", "Z"}], "]"}], "-", 
      RowBox[{
       SubscriptBox["\[PartialD]", "Y"], " ", 
       RowBox[{"Uz4", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}]}], "+", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayz1", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         SuperscriptBox[
          RowBox[{"Azz2", "[", 
           RowBox[{"Y", ",", "Z"}], "]"}], "2"]}], 
        SuperscriptBox["Leps2", "2"]], ")"}], "+", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayz3", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         RowBox[{"Azz2", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "+", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayz2", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         RowBox[{"Azz3", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}], "+", 
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Ayz1", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}], "*", 
         RowBox[{"Azz4", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], "Leps2"], ")"}]}], "]"}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 StyleBox[
  RowBox[{
   RowBox[{
   "Calculating", " ", "the", " ", "dP4", " ", "by", " ", "calculating", " ", 
    "the", " ", "fourth"}], "-", 
   RowBox[{"order", " ", "velocity", " ", 
    RowBox[{"(", "Uz4", ")"}]}]}], "Chapter"], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FullSimplify", "[", 
   RowBox[{"DSolve", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"Pgrad4", "[", "Z", "]"}], "==", 
        RowBox[{
         RowBox[{
          RowBox[{"Uz4", "''"}], "[", "Y", "]"}], "+", 
         RowBox[{"\[Beta]t", "*", 
          RowBox[{
           SubscriptBox["\[PartialD]", "Z"], " ", 
           RowBox[{"AUXzz5", "[", 
            RowBox[{"Y", ",", "Z"}], "]"}]}]}], "+", 
         RowBox[{"\[Beta]t", "*", 
          RowBox[{
           SubscriptBox["\[PartialD]", "Y"], " ", 
           RowBox[{"AUXyz5", "[", 
            RowBox[{"Y", ",", "Z"}], "]"}]}]}]}]}], ",", 
       RowBox[{
        RowBox[{
         RowBox[{"Uz4", "'"}], "[", "0", "]"}], "==", "0"}], ",", 
       RowBox[{
        RowBox[{"Uz4", "[", 
         RowBox[{"H", "[", "Z", "]"}], "]"}], "==", "0"}]}], "}"}], ",", 
     RowBox[{"Uz4", "[", "Y", "]"}], ",", "Y"}], "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Uz4", "[", 
    RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       RowBox[{"5600", " ", "Leps2", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "18"]}]]}], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["Y", "2"]}], "+", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "2"]}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2800", " ", "Leps2", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "18"], " ", 
        RowBox[{"Pgrad4", "[", "Z", "]"}]}], "-", 
       RowBox[{"135", " ", "Leps2", " ", 
        SuperscriptBox["Y", "8"], " ", "\[Beta]t", " ", 
        RowBox[{"(", 
         RowBox[{"4130", "+", 
          RowBox[{"3", " ", "\[Beta]t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1430"}], "+", 
             RowBox[{"441", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"27", " ", 
        SuperscriptBox["Y", "6"], " ", "\[Beta]t", " ", 
        RowBox[{"H", "[", "Z", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"9000", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "9"}], "+", 
             RowBox[{"4", " ", "\[Beta]t"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], "-", 
          RowBox[{"720", " ", "Leps2", " ", 
           RowBox[{"(", 
            RowBox[{"150", "+", 
             RowBox[{"\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "181"}], "+", 
                RowBox[{"50", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "4"]}], "+", 
          RowBox[{"Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"4550", "-", 
             RowBox[{"3618", " ", "\[Beta]t"}], "+", 
             RowBox[{"735", " ", 
              SuperscriptBox["\[Beta]t", "2"]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], "+", 
          RowBox[{"175", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"22", "-", 
             RowBox[{"30", " ", "\[Beta]t"}], "+", 
             RowBox[{"9", " ", 
              SuperscriptBox["\[Beta]t", "2"]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"54", " ", 
        SuperscriptBox["Y", "4"], " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "900"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "291"}], "+", 
             RowBox[{"92", " ", "\[Beta]t"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], "+", 
          RowBox[{"72", " ", "Leps2", " ", 
           RowBox[{"(", 
            RowBox[{"3450", "+", 
             RowBox[{"\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4149"}], "+", 
                RowBox[{"1150", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "4"]}], "+", 
          RowBox[{"Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "12350"}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{"4287", "-", 
                RowBox[{"815", " ", "\[Beta]t"}]}], ")"}], " ", 
              "\[Beta]t"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], "-", 
          RowBox[{"25", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"508", "+", 
             RowBox[{"3", " ", "\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "229"}], "+", 
                RowBox[{"63", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"54", " ", 
        SuperscriptBox["Y", "2"], " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "5"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"900", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "339"}], "+", 
             RowBox[{"188", " ", "\[Beta]t"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], "-", 
          RowBox[{"72", " ", "Leps2", " ", 
           RowBox[{"(", 
            RowBox[{"7050", "+", 
             RowBox[{"\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "7471"}], "+", 
                RowBox[{"2350", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "4"]}], "+", 
          RowBox[{"Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"28600", "-", 
             RowBox[{"31473", " ", "\[Beta]t"}], "+", 
             RowBox[{"6690", " ", 
              SuperscriptBox["\[Beta]t", "2"]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], "+", 
          RowBox[{"5", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"6910", "+", 
             RowBox[{"3", " ", "\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2881"}], "+", 
                RowBox[{"798", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"54", " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "7"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "900"}], " ", 
           RowBox[{"(", 
            RowBox[{"339", "+", 
             RowBox[{"116", " ", "\[Beta]t"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], "+", 
          RowBox[{"72", " ", "Leps2", " ", 
           RowBox[{"(", 
            RowBox[{"13950", "+", 
             RowBox[{"\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "5379"}], "+", 
                RowBox[{"1450", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "4"]}], "+", 
          RowBox[{"Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "39650"}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{"13029", "-", 
                RowBox[{"3545", " ", "\[Beta]t"}]}], ")"}], " ", 
              "\[Beta]t"}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], "-", 
          RowBox[{"5", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"10940", "+", 
             RowBox[{"3", " ", "\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "3827"}], "+", 
                RowBox[{"1197", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"27", " ", "Leps2", " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "9"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"125450", "+", 
             RowBox[{"3", " ", "\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "15772"}], "+", 
                RowBox[{"4015", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], "+", 
          RowBox[{"5", " ", 
           RowBox[{"(", 
            RowBox[{"37970", "+", 
             RowBox[{"3", " ", "\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "4856"}], "+", 
                RowBox[{"1323", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "-", 
       RowBox[{"27", " ", "Leps2", " ", "\[Beta]t", " ", 
        RowBox[{"(", 
         RowBox[{"9650", "+", 
          RowBox[{"39", " ", "\[Beta]t", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "94"}], "+", 
             RowBox[{"25", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "10"], " ", 
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "4", ")"}],
           Derivative],
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"135", " ", 
        SuperscriptBox["Y", "6"], " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"90", " ", 
              RowBox[{"(", 
               RowBox[{"17", "-", 
                RowBox[{"4", " ", "\[Beta]t"}]}], ")"}]}], "+", 
             RowBox[{"Leps2", " ", 
              RowBox[{"(", 
               RowBox[{"17060", "+", 
                RowBox[{"3", " ", "\[Beta]t", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "6845"}], "+", 
                   RowBox[{"1827", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["H", "\[Prime]",
                 MultilineFunction->None], "[", "Z", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}]}], "+", 
          RowBox[{"Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "70"}], "+", 
             RowBox[{"3", " ", 
              RowBox[{"(", 
               RowBox[{"30", "-", 
                RowBox[{"7", " ", "\[Beta]t"}]}], ")"}], " ", "\[Beta]t"}]}], 
            ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"27", " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "8"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"60", " ", 
              RowBox[{"(", 
               RowBox[{"1165", "+", 
                RowBox[{"348", " ", "\[Beta]t"}]}], ")"}]}], "+", 
             RowBox[{"Leps2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1657450"}], "+", 
                RowBox[{"3", " ", 
                 RowBox[{"(", 
                  RowBox[{"212152", "-", 
                   RowBox[{"57015", " ", "\[Beta]t"}]}], ")"}], " ", 
                 "\[Beta]t"}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["H", "\[Prime]",
                 MultilineFunction->None], "[", "Z", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}]}], "+", 
          RowBox[{"2", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"3050", "-", 
             RowBox[{"3132", " ", "\[Beta]t"}], "+", 
             RowBox[{"915", " ", 
              SuperscriptBox["\[Beta]t", "2"]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"54", " ", 
        SuperscriptBox["Y", "4"], " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "4"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "34350"}], "+", 
             RowBox[{"8280", " ", "\[Beta]t"}], "+", 
             RowBox[{"Leps2", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "264350"}], "+", 
                RowBox[{"316203", " ", "\[Beta]t"}], "-", 
                RowBox[{"85050", " ", 
                 SuperscriptBox["\[Beta]t", "2"]}]}], ")"}], " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["H", "\[Prime]",
                 MultilineFunction->None], "[", "Z", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}]}], "+", 
          RowBox[{"5", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"190", "+", 
             RowBox[{"3", " ", "\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "84"}], "+", 
                RowBox[{"19", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "+", 
       RowBox[{"54", " ", 
        SuperscriptBox["Y", "2"], " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "6"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{"34950", "-", 
             RowBox[{"16920", " ", "\[Beta]t"}], "+", 
             RowBox[{"Leps2", " ", 
              RowBox[{"(", 
               RowBox[{"454900", "+", 
                RowBox[{"3", " ", "\[Beta]t", " ", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "158299"}], "+", 
                   RowBox[{"48825", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], 
              " ", 
              SuperscriptBox[
               RowBox[{
                SuperscriptBox["H", "\[Prime]",
                 MultilineFunction->None], "[", "Z", "]"}], "2"]}]}], ")"}], 
           " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}]}], "-", 
          RowBox[{"2", " ", "Leps2", " ", 
           SuperscriptBox["Y", "2"], " ", 
           RowBox[{"(", 
            RowBox[{"1100", "+", 
             RowBox[{"3", " ", "\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "453"}], "+", 
                RowBox[{"110", " ", "\[Beta]t"}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}]}], 
      ")"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", 
       RowBox[{"H", "[", "Z", "]"}]], 
      RowBox[{
       RowBox[{"Uz4", "[", 
        RowBox[{"Y", ",", "Z"}], "]"}], 
       RowBox[{"\[DifferentialD]", "Y"}]}]}], "==", "0"}], ",", 
    RowBox[{"Pgrad4", "[", "Z", "]"}]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Pgrad4", "[", "Z_", "]"}], "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     FractionBox["1", 
      RowBox[{"13475", " ", "Leps2", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "11"]}]], "648", " ", "\[Beta]t", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"138600", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "2"]}], "+", 
       RowBox[{"30800", " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "2"]}], "-", 
       RowBox[{"369600", " ", "Leps2", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "4"]}], "+", 
       RowBox[{"121198", " ", "Leps2", " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "4"]}], "-", 
       RowBox[{"30800", " ", "Leps2", " ", 
        SuperscriptBox["\[Beta]t", "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "4"]}], "-", 
       RowBox[{"15785", " ", 
        RowBox[{"H", "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "-", 
       RowBox[{"3080", " ", "\[Beta]t", " ", 
        RowBox[{"H", "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"303450", " ", "Leps2", " ", 
        RowBox[{"H", "[", "Z", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "-", 
       RowBox[{"98571", " ", "Leps2", " ", "\[Beta]t", " ", 
        RowBox[{"H", "[", "Z", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"24990", " ", "Leps2", " ", 
        SuperscriptBox["\[Beta]t", "2"], " ", 
        RowBox[{"H", "[", "Z", "]"}], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}]}], "-", 
       RowBox[{"22750", " ", "Leps2", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "2"]}], "+", 
       RowBox[{"7211", " ", "Leps2", " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "2"]}], "-", 
       RowBox[{"1750", " ", "Leps2", " ", 
        SuperscriptBox["\[Beta]t", "2"], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], "2"]}], "-", 
       RowBox[{"34650", " ", "Leps2", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"11191", " ", "Leps2", " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "Z", "]"}]}], "-", 
       RowBox[{"2870", " ", "Leps2", " ", 
        SuperscriptBox["\[Beta]t", "2"], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "Z", "]"}], " ", 
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"1750", " ", "Leps2", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "4", ")"}],
           Derivative],
          MultilineFunction->None], "[", "Z", "]"}]}], "-", 
       RowBox[{"556", " ", "Leps2", " ", "\[Beta]t", " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "4", ")"}],
           Derivative],
          MultilineFunction->None], "[", "Z", "]"}]}], "+", 
       RowBox[{"140", " ", "Leps2", " ", 
        SuperscriptBox["\[Beta]t", "2"], " ", 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "3"], " ", 
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "4", ")"}],
           Derivative],
          MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Uy4", "[", 
     RowBox[{"Y_", ",", "Z_"}], "]"}], "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"-", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "Y"], 
       RowBox[{
        RowBox[{
         SubscriptBox["\[PartialD]", "Z"], " ", 
         RowBox[{"Uz4", "[", 
          RowBox[{"Y", ",", "Z"}], "]"}]}], 
        RowBox[{"\[DifferentialD]", "Y"}]}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "The", " ", "pressure", " ", "drop", " ", "correction", " ", "at", " ", 
      "O", 
      RowBox[{"(", 
       SuperscriptBox["De", "4"], ")"}], " ", "calculated", " ", "using", " ",
       "the", " ", "fourth"}], "-", 
     RowBox[{"order", " ", "velocity", " ", 
      RowBox[{
       RowBox[{"(", "Uz4", ")"}], ".", " ", "We"}], " ", "denote", " ", 
      "this", " ", "by", " ", "dP4F1"}]}], ",", " ", 
    RowBox[{
    "where", " ", "F1", " ", "stands", " ", "for", " ", "formulation", " ", 
     "1", " ", 
     RowBox[{"(", 
      RowBox[{"velocity", " ", "formulation"}], ")"}]}]}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dP4F1", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "1"], " ", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"Pgrad4", "[", "Z", "]"}]}], 
      RowBox[{"\[DifferentialD]", "Z"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"H", "[", "Z_", "]"}], "=", 
    FractionBox["H0", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"H0", "-", "1"}], ")"}], "Z"}], "+", "1"}]]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "Shape", " ", "function", " ", "given", " ", "in", " ", "equation", " ", 
    RowBox[{"(", "5.1", ")"}], " ", "to", " ", "check", " ", "the", " ", 
    "consistancy", " ", "of", " ", "our", " ", "solutions", " ", "at", " ", 
    "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "4"], ")"}]}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  StyleBox[
   RowBox[{
   "Calculating", " ", "the", " ", "dP4", " ", "from", " ", "the", " ", 
    "integral", " ", "formulation", " ", "given", " ", "in", " ", 
    RowBox[{"Eq", ".", " ", 
     RowBox[{"(", 
      RowBox[{"B", " ", "13"}], ")"}]}]}], "Chapter"], 
  StyleBox[" ", "Chapter"], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"ENSCart", " ", "=", " ", 
    RowBox[{
    "Elastic", " ", "normal", " ", "stress", " ", "term", " ", "in", " ", 
     "Cartesian", " ", "coordinates"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"ESSCart", " ", "=", " ", 
    RowBox[{
    "Elastic", " ", "shear", " ", "stress", " ", "term", " ", "in", " ", 
     "Cartesian", " ", "coordinates"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ENSCart4", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Beta]t", 
        RowBox[{
         SubsuperscriptBox["\[Integral]", "0", 
          RowBox[{"H", "[", "0", "]"}]], 
         RowBox[{
          RowBox[{"AUXzz5", "[", 
           RowBox[{"Y", ",", "Z"}], "]"}], "*", 
          RowBox[{"Uzb", "[", 
           RowBox[{"Y", ",", "Z"}], "]"}], 
          RowBox[{"\[DifferentialD]", "Y"}]}]}]}], "/.", 
       RowBox[{"Z", "->", "0"}]}], ")"}], "-", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"\[Beta]t", 
        RowBox[{
         SubsuperscriptBox["\[Integral]", "0", 
          RowBox[{"H", "[", "1", "]"}]], 
         RowBox[{
          RowBox[{"AUXzz5", "[", 
           RowBox[{"Y", ",", "Z"}], "]"}], "*", 
          RowBox[{"Uzb", "[", 
           RowBox[{"Y", ",", "Z"}], "]"}], 
          RowBox[{"\[DifferentialD]", "Y"}]}]}]}], "/.", 
       RowBox[{"Z", "->", "1"}]}], ")"}], "+", 
     RowBox[{"\[Beta]t", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", 
         RowBox[{"H", "[", "Z", "]"}]], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"AUXzz5", "[", 
            RowBox[{"Y", ",", "Z"}], "]"}], "*", 
           RowBox[{
            SubscriptBox["\[PartialD]", "Z"], 
            RowBox[{"Uzb", "[", 
             RowBox[{"Y", ",", "Z"}], "]"}]}]}], ")"}], 
         RowBox[{"\[DifferentialD]", "Y"}], 
         RowBox[{"\[DifferentialD]", "Z"}]}]}]}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ESSCart4", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"\[Beta]t", 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "1"], 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", 
         RowBox[{"H", "[", "Z", "]"}]], 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"AUXyz5", "[", 
            RowBox[{"Y", ",", "Z"}], "]"}], "*", 
           RowBox[{
            SubscriptBox["\[PartialD]", "Y"], 
            RowBox[{"Uzb", "[", 
             RowBox[{"Y", ",", "Z"}], "]"}]}]}], ")"}], 
         RowBox[{"\[DifferentialD]", "Y"}], 
         RowBox[{"\[DifferentialD]", "Z"}]}]}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "The", " ", "pressure", " ", "drop", " ", "correction", " ", "at", " ", 
     "O", 
     RowBox[{"(", 
      SuperscriptBox["De", "4"], ")"}], " ", "calculated", " ", "from", " ", 
     "the", " ", "integral", " ", 
     RowBox[{"formulation", ".", " ", "We"}], " ", "denote", " ", "this", " ",
      "by", " ", "dP4F2"}], ",", " ", 
    RowBox[{
    "where", " ", "F2", " ", "stands", " ", "for", " ", "formulation", " ", 
     "2", " ", 
     RowBox[{"(", 
      RowBox[{"integral", " ", "formulation", " ", "given", " ", "in", " ", 
       RowBox[{"Eq", ".", " ", 
        RowBox[{"(", 
         RowBox[{"B", " ", "13"}], ")"}]}]}], ")"}]}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dP4F2", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{"ENSCart4", "+", "ESSCart4"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Final", " ", "expression", " ", "for", " ", "the", " ", "pressure", " ", 
    "drop", " ", "at", " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "4"], ")"}], " ", "after", " ", "simplifications"}],
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"dP4Final", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"3888", " ", "\[Beta]t", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"8", " ", "\[Beta]t"}], "+", "25"}], ")"}], " "}], 
        RowBox[{"175", " ", "Leps2", " "}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "1", "]"}], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"H", "[", "1", "]"}], "10"], " "}]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "0", "]"}], 
          RowBox[{
           SuperscriptBox[
            RowBox[{"H", "[", "0", "]"}], "10"], " "}]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"648", "\[Beta]t", "  "}], 
        RowBox[{"175", " ", "Leps2", " "}]], " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{"55", "-", 
              RowBox[{"8", " ", "\[Beta]t"}]}], ")"}], " ", 
            RowBox[{"H", "[", "Z", "]"}], " ", 
            RowBox[{
             SuperscriptBox["H", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}]}], "+", 
           RowBox[{"20", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"4", " ", "\[Beta]t"}], "-", "15"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{
              SuperscriptBox["H", "\[Prime]",
               MultilineFunction->None], "[", "Z", "]"}], "2"]}]}], 
          SuperscriptBox[
           RowBox[{"H", "[", "Z", "]"}], "11"]], 
         RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
      RowBox[{"\[Beta]t", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         FractionBox[
          RowBox[{"3240", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{"41", "-", 
                RowBox[{"70", " ", "\[Beta]t"}]}], ")"}]}], "+", "910"}], 
            ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"]}], 
          RowBox[{"13475", " ", 
           SuperscriptBox[
            RowBox[{"H", "[", "Z", "]"}], "9"]}]], 
         RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
      RowBox[{"\[Beta]t", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         FractionBox[
          RowBox[{"4536", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{"119", "-", 
                RowBox[{"82", " ", "\[Beta]t"}]}], ")"}]}], "+", "750"}], 
            ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "3", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}], 
          RowBox[{"13475", " ", 
           SuperscriptBox[
            RowBox[{"H", "[", "Z", "]"}], "9"]}]], 
         RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
      RowBox[{"\[Beta]t", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         FractionBox[
          RowBox[{"1296", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"2", " ", "\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"7", " ", "\[Beta]t"}], "-", "5"}], ")"}]}], "-", 
             "175"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["H", 
             TagBox[
              RowBox[{"(", "4", ")"}],
              Derivative],
             MultilineFunction->None], "[", "Z", "]"}]}], 
          RowBox[{"13475", " ", 
           SuperscriptBox[
            RowBox[{"H", "[", "Z", "]"}], "8"]}]], 
         RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
      RowBox[{"\[Beta]t", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         FractionBox[
          RowBox[{"9072", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"11", " ", "\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{"83", "-", 
                RowBox[{"40", " ", "\[Beta]t"}]}], ")"}]}], "+", "2400"}], 
            ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "4"]}], 
          RowBox[{"13475", " ", 
           SuperscriptBox[
            RowBox[{"H", "[", "Z", "]"}], "11"]}]], 
         RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
      RowBox[{"\[Beta]t", " ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", "0", "1"], 
        RowBox[{
         FractionBox[
          RowBox[{"1944", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"\[Beta]t", " ", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"1666", " ", "\[Beta]t"}], "-", "2789"}], ")"}]}], 
             "-", "12950"}], ")"}], " ", 
           SuperscriptBox[
            RowBox[{
             SuperscriptBox["H", "\[Prime]",
              MultilineFunction->None], "[", "Z", "]"}], "2"], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}]}], 
          RowBox[{"13475", " ", 
           SuperscriptBox[
            RowBox[{"H", "[", "Z", "]"}], "10"]}]], 
         RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"5184", " ", "\[Beta]t", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Beta]t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"7", " ", "\[Beta]t"}], "-", "24"}], ")"}]}], "+", 
           "175"}], ")"}]}], 
        RowBox[{"13475", " "}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["H", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "0", "]"}], 
          SuperscriptBox[
           RowBox[{"H", "[", "0", "]"}], "8"]], "-", 
         FractionBox[
          RowBox[{
           SuperscriptBox["H", 
            TagBox[
             RowBox[{"(", "3", ")"}],
             Derivative],
            MultilineFunction->None], "[", "1", "]"}], 
          SuperscriptBox[
           RowBox[{"H", "[", "1", "]"}], "8"]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"2592", " ", "\[Beta]t", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"3", " ", "\[Beta]t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"175", " ", "\[Beta]t"}], "-", "618"}], ")"}]}], "+", 
           "4550"}], ")"}]}], 
        RowBox[{"13475", " "}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "1", "]"}], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "1", "]"}]}], 
          SuperscriptBox[
           RowBox[{"H", "[", "1", "]"}], "9"]], "-", 
         FractionBox[
          RowBox[{
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "0", "]"}], " ", 
           RowBox[{
            SuperscriptBox["H", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "0", "]"}]}], 
          SuperscriptBox[
           RowBox[{"H", "[", "0", "]"}], "9"]]}], ")"}]}], "+", 
      RowBox[{
       FractionBox[
        RowBox[{"3888", " ", "\[Beta]t", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"11", " ", "\[Beta]t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"8", " ", "\[Beta]t"}], "-", "29"}], ")"}]}], "+", 
           "800"}], ")"}], " "}], 
        RowBox[{"1925", " "}]], 
       RowBox[{"(", 
        RowBox[{
         FractionBox[
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "0", "]"}], "3"], 
          SuperscriptBox[
           RowBox[{"H", "[", "0", "]"}], "10"]], "-", 
         FractionBox[
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "1", "]"}], "3"], 
          SuperscriptBox[
           RowBox[{"H", "[", "1", "]"}], "10"]]}], ")"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "To", " ", "check", " ", "the", " ", "consistency", " ", "of", " ", "our", 
    " ", "solution", " ", "and", " ", "final", " ", "expression", " ", "at", 
    " ", "O", 
    RowBox[{"(", 
     SuperscriptBox["De", "4"], ")"}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"FullSimplify", "[", 
  RowBox[{"(", 
   RowBox[{"dP4Final", "-", "dP4F1"}], ")"}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.904273391737431*^9, 3.904273392676696*^9}, {
   3.91370132114642*^9, 3.9137014562823305`*^9}, {3.9137020066975975`*^9, 
   3.9137020403448896`*^9}, {3.913704992671501*^9, 3.913705002049178*^9}, {
   3.9232794705488014`*^9, 3.9232795200958633`*^9}, {3.9232795545445585`*^9, 
   3.923279585107746*^9}, {3.923283765049188*^9, 3.9232838547817683`*^9}, {
   3.9232839022184787`*^9, 3.923284223379707*^9}, {3.9232844394271173`*^9, 
   3.9232846413366747`*^9}, {3.923284674955617*^9, 3.923284680315709*^9}, {
   3.923284733212208*^9, 3.92328502372261*^9}, {3.923285067774581*^9, 
   3.923285605709578*^9}, {3.923285668584981*^9, 3.923285735043973*^9}, {
   3.923285768272393*^9, 3.92328586673771*^9}, {3.923285972384941*^9, 
   3.923285977899613*^9}, {3.9232861243652086`*^9, 3.9232862842694263`*^9}, {
   3.923286331010832*^9, 3.923286380071435*^9}, {3.9232864660009274`*^9, 
   3.9232864710164137`*^9}, {3.9232868356126823`*^9, 3.923286836844297*^9}, {
   3.923287452801679*^9, 3.923287481305966*^9}, {3.9232875222791853`*^9, 
   3.9232875643406687`*^9}, {3.923287704620663*^9, 3.9232877065324845`*^9}, {
   3.9232879722944717`*^9, 3.9232879867613816`*^9}, 3.9232896062058277`*^9, {
   3.923305189478295*^9, 3.9233051910999355`*^9}, {3.9233672409850144`*^9, 
   3.923367331555543*^9}, {3.9233674631531167`*^9, 3.9233675996535425`*^9}, {
   3.9233676800199666`*^9, 3.923367770776123*^9}, {3.923445603416795*^9, 
   3.923445736557029*^9}, {3.9234457729495955`*^9, 3.9234458004206686`*^9}, {
   3.923445859832423*^9, 3.923445860846633*^9}, {3.9234460125217433`*^9, 
   3.9234461265345774`*^9}, {3.9234470265378876`*^9, 
   3.9234471781023283`*^9}, {3.9235364344484563`*^9, 
   3.9235365645908985`*^9}, {3.92353663811041*^9, 3.923536649718007*^9}, {
   3.923536682620841*^9, 3.923536685271104*^9}, {3.923555863879134*^9, 
   3.9235558875573497`*^9}, {3.9235559368043203`*^9, 3.923555979429712*^9}, {
   3.923561314814271*^9, 3.9235613541745863`*^9}, {3.9235614211615553`*^9, 
   3.9235614253352356`*^9}, {3.923561628050252*^9, 3.9235616339405117`*^9}, {
   3.9235619960661716`*^9, 3.923562001517967*^9}, {3.9235622014189014`*^9, 
   3.92356221575021*^9}, {3.923562397309414*^9, 3.923562427571205*^9}, {
   3.9235625033913546`*^9, 3.923562506713151*^9}, 3.9235625550557756`*^9, {
   3.923562598987373*^9, 3.92356260202536*^9}, 3.923562639453344*^9, {
   3.923562730924285*^9, 3.9235627573918333`*^9}, {3.923563195547357*^9, 
   3.923563229549756*^9}, {3.923563290889717*^9, 3.92356329212731*^9}, 
   3.923563387255212*^9, {3.9235634876061387`*^9, 3.923563607325285*^9}, {
   3.9235636379268255`*^9, 3.9235636382899785`*^9}, {3.9235636859745293`*^9, 
   3.923563690121303*^9}, 3.9235637989815416`*^9, {3.923563915513732*^9, 
   3.923563975851342*^9}, {3.9235640359983473`*^9, 3.9235640378103237`*^9}, {
   3.923564435553624*^9, 3.923564444194731*^9}, {3.9235646363882275`*^9, 
   3.9235646540208597`*^9}, {3.923564720724797*^9, 3.9235647317723813`*^9}, {
   3.9235651349277716`*^9, 3.923565139055236*^9}, {3.9235652017494144`*^9, 
   3.9235652706388273`*^9}, {3.9235653119892354`*^9, 3.923565319209856*^9}, {
   3.9235654032352557`*^9, 3.9235654072834997`*^9}, {3.923565441774128*^9, 
   3.9235654961962175`*^9}, {3.92356560918172*^9, 3.923565629053092*^9}, {
   3.9235657632707396`*^9, 3.9235657798949256`*^9}, {3.9235658617757454`*^9, 
   3.9235658890386114`*^9}, {3.9235661173781214`*^9, 3.923566169401187*^9}, 
   3.9235663804639845`*^9, {3.923566526546742*^9, 3.923566563082416*^9}, {
   3.9235666682166796`*^9, 3.923566668530897*^9}, {3.9236189926708097`*^9, 
   3.923618997234359*^9}, {3.9236190391690645`*^9, 3.9236190591792445`*^9}, {
   3.9236190894394636`*^9, 3.9236191191514897`*^9}, {3.9236193943369093`*^9, 
   3.9236194049846697`*^9}, {3.9236194687643986`*^9, 
   3.9236194734916477`*^9}, {3.9236195420710983`*^9, 3.923619565673805*^9}, {
   3.9236196064933796`*^9, 3.9236196607750034`*^9}, {3.923619693456236*^9, 
   3.9236197529439106`*^9}, {3.92361983810398*^9, 3.9236198655866175`*^9}, {
   3.9236199103051767`*^9, 3.9236199913963823`*^9}, {3.923620055918029*^9, 
   3.923620261465493*^9}, {3.9236202919346104`*^9, 3.92362035544849*^9}, {
   3.923624051429079*^9, 3.92362407794016*^9}, {3.923624601242117*^9, 
   3.923624607245241*^9}, {3.923629189563803*^9, 3.9236292087185755`*^9}, {
   3.923629247725299*^9, 3.9236292560961895`*^9}, {3.9236293006356664`*^9, 
   3.923629333747815*^9}, {3.923629369154441*^9, 3.923629480730651*^9}, {
   3.9236430402685175`*^9, 3.923643041043152*^9}, {3.9239021659665146`*^9, 
   3.9239021927454033`*^9}, {3.9239026587039647`*^9, 
   3.9239027363473363`*^9}, {3.9239030611792326`*^9, 3.923903071018384*^9}, {
   3.9239031185313926`*^9, 3.923903356814089*^9}, {3.9244191650987177`*^9, 
   3.924419252848138*^9}, {3.924419293264603*^9, 3.924419336054224*^9}, {
   3.924419375577377*^9, 3.9244193759959574`*^9}, {3.9244194251724*^9, 
   3.9244194254997964`*^9}, {3.924419517792775*^9, 3.924419534876563*^9}, {
   3.9244196160483665`*^9, 3.924419619949626*^9}, {3.924419687066387*^9, 
   3.924419691270049*^9}, 3.9244197844359713`*^9, {3.924419871618638*^9, 
   3.92441989595584*^9}, {3.924419985795506*^9, 3.924419996836521*^9}, {
   3.924425105055997*^9, 3.924425109442933*^9}, {3.9244251561545973`*^9, 
   3.924425190620146*^9}, {3.9245169197847123`*^9, 3.924516927106892*^9}, 
   3.9245170807316074`*^9, {3.924517121941253*^9, 3.9245171675347166`*^9}, {
   3.924569828469736*^9, 3.924569866758768*^9}, {3.924569964406356*^9, 
   3.9245701103711567`*^9}, {3.9305539845099487`*^9, 
   3.9305540018750453`*^9}, {3.9306502368825693`*^9, 3.930650242509593*^9}, {
   3.930650421462579*^9, 3.9306504503713264`*^9}, 3.930650679383108*^9, {
   3.930650808813445*^9, 
   3.9306508193151865`*^9}},ExpressionUUID->"2f23cd0c-99f6-4820-b91c-\
a2c2acf1d8b7"],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{3.924420065134165*^9},
 CellLabel->"Out[41]=",ExpressionUUID->"518d760e-7524-43a2-8ba7-7568808573f4"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Pressure drop in a contracting channel ", "Title",
 CellChangeTimes->{{3.9235367240267687`*^9, 3.9235367503563004`*^9}, {
   3.9235374267852945`*^9, 3.923537435504424*^9}, {3.92353866589178*^9, 
   3.923538695617895*^9}, {3.923554426351348*^9, 3.9235544267720404`*^9}, {
   3.923554579313403*^9, 3.9235545908747416`*^9}, 
   3.9245171999823246`*^9},ExpressionUUID->"13c6c320-1d45-4fec-bf7e-\
17725cacf49c"],

Cell[CellGroupData[{

Cell["Hyperbolic shape given in equation (5.1) ", "Section",
 CellChangeTimes->{{3.923554607690268*^9, 3.923554631467454*^9}, {
  3.9305540244281063`*^9, 3.9305540248117104`*^9}, {3.930650259319566*^9, 
  3.9306502642843437`*^9}},ExpressionUUID->"251ea895-0ad8-43e0-aa4e-\
d418cc4a8df5"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"H", "[", "Z_", "]"}], "=", 
   FractionBox["H0", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{"H0", "-", "1"}], ")"}], "Z"}], "+", "1"}]]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"dP0", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     FractionBox["3", 
      SuperscriptBox[
       RowBox[{"H", "[", "Z", "]"}], "3"]], 
     RowBox[{"\[DifferentialD]", "Z"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"dP1", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    FractionBox["9", "2"], " ", "\[Beta]t", " ", 
    RowBox[{"(", 
     RowBox[{
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"H", "[", "0", "]"}], "4"]], "-", 
      FractionBox["1", 
       SuperscriptBox[
        RowBox[{"H", "[", "1", "]"}], "4"]]}], ")"}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"dP2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "1"], 
    RowBox[{
     FractionBox[
      RowBox[{"324", " ", "\[Beta]t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"14", " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], "2"]}], "-", 
         RowBox[{"3", " ", 
          RowBox[{"H", "[", "Z", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}]}]}], ")"}]}], 
      RowBox[{"35", " ", 
       SuperscriptBox[
        RowBox[{"H", "[", "Z", "]"}], "7"]}]], 
     RowBox[{"\[DifferentialD]", "Z"}]}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"dP3", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"2673", " ", "\[Beta]t", " "}], 
       RowBox[{"70", " ", "Leps2"}]]}], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"H", "[", "0", "]"}], "8"], " "}]], "-", 
       FractionBox["1", 
        RowBox[{
         SuperscriptBox[
          RowBox[{"H", "[", "1", "]"}], "8"], " "}]]}], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"648", "  ", "\[Beta]t", " ", 
       RowBox[{"(", 
        RowBox[{"9", "-", "\[Beta]t"}], ")"}]}], 
      RowBox[{"35", " "}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "0", "]"}], "2"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"H", "[", "0", "]"}], "8"], " "}]], "-", 
       FractionBox[
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "1", "]"}], "2"], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"H", "[", "1", "]"}], "8"], " "}]]}], ")"}]}], "-", 
    RowBox[{
     FractionBox[
      RowBox[{"216", " ", "\[Beta]t", " ", 
       RowBox[{"(", 
        RowBox[{"8", "-", "\[Beta]t"}], ")"}]}], "35"], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "0", "]"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"H", "[", "0", "]"}], "7"], " "}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["H", "\[Prime]\[Prime]",
          MultilineFunction->None], "[", "1", "]"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"H", "[", "1", "]"}], "7"], " "}]]}], ")"}]}]}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"dP4", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      RowBox[{"3888", " ", "\[Beta]t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", "\[Beta]t"}], "+", "25"}], ")"}], " "}], 
      RowBox[{"175", " ", "Leps2", " "}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "1", "]"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"H", "[", "1", "]"}], "10"], " "}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["H", "\[Prime]",
          MultilineFunction->None], "[", "0", "]"}], 
        RowBox[{
         SuperscriptBox[
          RowBox[{"H", "[", "0", "]"}], "10"], " "}]]}], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"648", "\[Beta]t", "  "}], 
      RowBox[{"175", " ", "Leps2", " "}]], " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{"55", "-", 
            RowBox[{"8", " ", "\[Beta]t"}]}], ")"}], " ", 
          RowBox[{"H", "[", "Z", "]"}], " ", 
          RowBox[{
           SuperscriptBox["H", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}]}], "+", 
         RowBox[{"20", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", "\[Beta]t"}], "-", "15"}], ")"}], " ", 
          SuperscriptBox[
           RowBox[{
            SuperscriptBox["H", "\[Prime]",
             MultilineFunction->None], "[", "Z", "]"}], "2"]}]}], 
        SuperscriptBox[
         RowBox[{"H", "[", "Z", "]"}], "11"]], 
       RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
    RowBox[{"\[Beta]t", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       FractionBox[
        RowBox[{"3240", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Beta]t", " ", 
            RowBox[{"(", 
             RowBox[{"41", "-", 
              RowBox[{"70", " ", "\[Beta]t"}]}], ")"}]}], "+", "910"}], ")"}],
          " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}], "2"]}], 
        RowBox[{"13475", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "9"]}]], 
       RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
    RowBox[{"\[Beta]t", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       FractionBox[
        RowBox[{"4536", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Beta]t", " ", 
            RowBox[{"(", 
             RowBox[{"119", "-", 
              RowBox[{"82", " ", "\[Beta]t"}]}], ")"}]}], "+", "750"}], ")"}],
          " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", 
           TagBox[
            RowBox[{"(", "3", ")"}],
            Derivative],
           MultilineFunction->None], "[", "Z", "]"}]}], 
        RowBox[{"13475", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "9"]}]], 
       RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
    RowBox[{"\[Beta]t", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       FractionBox[
        RowBox[{"1296", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "\[Beta]t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"7", " ", "\[Beta]t"}], "-", "5"}], ")"}]}], "-", 
           "175"}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["H", 
           TagBox[
            RowBox[{"(", "4", ")"}],
            Derivative],
           MultilineFunction->None], "[", "Z", "]"}]}], 
        RowBox[{"13475", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "8"]}]], 
       RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
    RowBox[{"\[Beta]t", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       FractionBox[
        RowBox[{"9072", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"11", " ", "\[Beta]t", " ", 
            RowBox[{"(", 
             RowBox[{"83", "-", 
              RowBox[{"40", " ", "\[Beta]t"}]}], ")"}]}], "+", "2400"}], 
          ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}], "4"]}], 
        RowBox[{"13475", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "11"]}]], 
       RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
    RowBox[{"\[Beta]t", " ", 
     RowBox[{
      SubsuperscriptBox["\[Integral]", "0", "1"], 
      RowBox[{
       FractionBox[
        RowBox[{"1944", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"\[Beta]t", " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"1666", " ", "\[Beta]t"}], "-", "2789"}], ")"}]}], "-", 
           "12950"}], ")"}], " ", 
         SuperscriptBox[
          RowBox[{
           SuperscriptBox["H", "\[Prime]",
            MultilineFunction->None], "[", "Z", "]"}], "2"], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "Z", "]"}]}], 
        RowBox[{"13475", " ", 
         SuperscriptBox[
          RowBox[{"H", "[", "Z", "]"}], "10"]}]], 
       RowBox[{"\[DifferentialD]", "Z"}]}]}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"5184", " ", "\[Beta]t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Beta]t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"7", " ", "\[Beta]t"}], "-", "24"}], ")"}]}], "+", 
         "175"}], ")"}]}], 
      RowBox[{"13475", " "}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "0", "]"}], 
        SuperscriptBox[
         RowBox[{"H", "[", "0", "]"}], "8"]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["H", 
          TagBox[
           RowBox[{"(", "3", ")"}],
           Derivative],
          MultilineFunction->None], "[", "1", "]"}], 
        SuperscriptBox[
         RowBox[{"H", "[", "1", "]"}], "8"]]}], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"2592", " ", "\[Beta]t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", " ", "\[Beta]t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"175", " ", "\[Beta]t"}], "-", "618"}], ")"}]}], "+", 
         "4550"}], ")"}]}], 
      RowBox[{"13475", " "}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "1", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "1", "]"}]}], 
        SuperscriptBox[
         RowBox[{"H", "[", "1", "]"}], "9"]], "-", 
       FractionBox[
        RowBox[{
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "0", "]"}], " ", 
         RowBox[{
          SuperscriptBox["H", "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "0", "]"}]}], 
        SuperscriptBox[
         RowBox[{"H", "[", "0", "]"}], "9"]]}], ")"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"3888", " ", "\[Beta]t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"11", " ", "\[Beta]t", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"8", " ", "\[Beta]t"}], "-", "29"}], ")"}]}], "+", 
         "800"}], ")"}], " "}], 
      RowBox[{"1925", " "}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox[
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "0", "]"}], "3"], 
        SuperscriptBox[
         RowBox[{"H", "[", "0", "]"}], "10"]], "-", 
       FractionBox[
        SuperscriptBox[
         RowBox[{
          SuperscriptBox["H", "\[Prime]",
           MultilineFunction->None], "[", "1", "]"}], "3"], 
        SuperscriptBox[
         RowBox[{"H", "[", "1", "]"}], "10"]]}], ")"}]}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.9235367939140406`*^9, 3.9235368477783556`*^9}, {
   3.923536893307844*^9, 3.9235369394229403`*^9}, {3.923563823181768*^9, 
   3.9235638417375956`*^9}, {3.9235641392732716`*^9, 
   3.9235641402785387`*^9}, {3.9235643209148445`*^9, 3.923564322038333*^9}, {
   3.9235644810254173`*^9, 3.9235644821616964`*^9}, {3.923565153844344*^9, 
   3.9235651548436847`*^9}, {3.9235656441036916`*^9, 3.923565645031003*^9}, 
   3.9235657999135075`*^9, 3.9235665899104805`*^9, 3.923566632945022*^9, {
   3.9236203659162626`*^9, 3.9236203669081697`*^9}, {3.923644295977479*^9, 
   3.9236442968028374`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"b28b0f00-813a-4d6e-a923-2cc28c9a7469"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "H0"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["H0", "2"]}], ")"}]}], 
  RowBox[{"4", " ", 
   SuperscriptBox["H0", "3"]}]]], "Output",
 CellChangeTimes->{3.9235369469406824`*^9, 3.923563849776847*^9, 
  3.923564147388777*^9, 3.9235643325021815`*^9, 3.923564494313805*^9, 
  3.92356516215097*^9, 3.9235656579614987`*^9, 3.923566640236704*^9, 
  3.923620378208068*^9, 3.923644336675559*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"f34b9e4c-cb0b-49a9-8e6d-d64d1e40a02b"],

Cell[BoxData[
 RowBox[{
  FractionBox["9", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    FractionBox["1", 
     SuperscriptBox["H0", "4"]]}], ")"}], " ", "\[Beta]t"}]], "Output",
 CellChangeTimes->{3.9235369469406824`*^9, 3.923563849776847*^9, 
  3.923564147388777*^9, 3.9235643325021815`*^9, 3.923564494313805*^9, 
  3.92356516215097*^9, 3.9235656579614987`*^9, 3.923566640236704*^9, 
  3.923620378208068*^9, 3.9236443366912727`*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"53cdc1b5-235f-4ef7-b6b5-0e59cb8dabb6"],

Cell[BoxData[
 FractionBox[
  RowBox[{"648", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "H0"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["H0", "2"]}], ")"}], " ", "\[Beta]t"}], 
  RowBox[{"35", " ", 
   SuperscriptBox["H0", "5"]}]]], "Output",
 CellChangeTimes->{3.9235369469406824`*^9, 3.923563849776847*^9, 
  3.923564147388777*^9, 3.9235643325021815`*^9, 3.923564494313805*^9, 
  3.92356516215097*^9, 3.9235656579614987`*^9, 3.923566640236704*^9, 
  3.923620378208068*^9, 3.9236443366912727`*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"37fbd7a5-365d-4ba4-ba35-84767d96fb1e"],

Cell[BoxData[
 FractionBox[
  RowBox[{"27", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["H0", "4"]}], ")"}], " ", "\[Beta]t", " ", 
   RowBox[{"(", 
    RowBox[{"99", "+", 
     RowBox[{
      SuperscriptBox["H0", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"99", " ", 
         SuperscriptBox["H0", "2"]}], "-", 
        RowBox[{"176", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", "Leps2"}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", "Leps2", " ", 
         "\[Beta]t"}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"70", " ", 
   SuperscriptBox["H0", "8"], " ", "Leps2"}]]], "Output",
 CellChangeTimes->{3.9235369469406824`*^9, 3.923563849776847*^9, 
  3.923564147388777*^9, 3.9235643325021815`*^9, 3.923564494313805*^9, 
  3.92356516215097*^9, 3.9235656579614987`*^9, 3.923566640236704*^9, 
  3.923620378208068*^9, 3.923644336754901*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"b5ce825c-28a0-4b78-ab3f-2c27aabb625c"],

Cell[BoxData[
 FractionBox[
  RowBox[{"162", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "H0"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["H0", "2"]}], ")"}], " ", "\[Beta]t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "53515"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["H0", "4"]}], ")"}]}], "+", 
     RowBox[{"19600", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
      SuperscriptBox["H0", "2"], " ", "Leps2"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6160", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["H0", "4"]}], ")"}]}], "+", 
        RowBox[{"3351", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
         SuperscriptBox["H0", "2"], " ", "Leps2"}]}], ")"}], " ", 
      "\[Beta]t"}], "+", 
     RowBox[{"1680", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
      SuperscriptBox["H0", "2"], " ", "Leps2", " ", 
      SuperscriptBox["\[Beta]t", "2"]}]}], ")"}]}], 
  RowBox[{"13475", " ", 
   SuperscriptBox["H0", "9"], " ", "Leps2"}]]], "Output",
 CellChangeTimes->{3.9235369469406824`*^9, 3.923563849776847*^9, 
  3.923564147388777*^9, 3.9235643325021815`*^9, 3.923564494313805*^9, 
  3.92356516215097*^9, 3.9235656579614987`*^9, 3.923566640236704*^9, 
  3.923620378208068*^9, 3.9236443371172657`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"73a37db8-a10b-4e5f-a1b6-805d3499f597"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plot of pressure drop versus De", "Title",
 CellChangeTimes->{{3.913702105707099*^9, 3.913702123669105*^9}, {
  3.914299219561559*^9, 
  3.914299231687747*^9}},ExpressionUUID->"d860aeed-efd9-4108-92e1-\
34429f0f53e6"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"\[Beta]t", "=", "0.4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"H0", "=", "4"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Leps2", "=", "0.5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dP0", "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"3", " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "H0"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["H0", "2"]}], ")"}]}], 
     RowBox[{"4", " ", 
      SuperscriptBox["H0", "3"]}]], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dP1", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{
     FractionBox["9", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       FractionBox["1", 
        SuperscriptBox["H0", "4"]]}], ")"}], " ", "\[Beta]t"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dP2", "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"648", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "H0"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["H0", "2"]}], ")"}], " ", "\[Beta]t"}], 
     RowBox[{"35", " ", 
      SuperscriptBox["H0", "5"]}]], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dP3", "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"27", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        SuperscriptBox["H0", "4"]}], ")"}], " ", "\[Beta]t", " ", 
      RowBox[{"(", 
       RowBox[{"99", "+", 
        RowBox[{
         SuperscriptBox["H0", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"99", " ", 
            SuperscriptBox["H0", "2"]}], "-", 
           RowBox[{"176", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", "Leps2"}], 
           "+", 
           RowBox[{"16", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", "Leps2", 
            " ", "\[Beta]t"}]}], ")"}]}]}], ")"}]}], 
     RowBox[{"70", " ", 
      SuperscriptBox["H0", "8"], " ", "Leps2"}]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dP4", "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{"162", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", "H0"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["H0", "2"]}], ")"}], " ", "\[Beta]t", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "53515"}], " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["H0", "4"]}], ")"}]}], "+", 
        RowBox[{"19600", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
         SuperscriptBox["H0", "2"], " ", "Leps2"}], "-", 
        RowBox[{"2", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"6160", " ", 
            RowBox[{"(", 
             RowBox[{"1", "+", 
              SuperscriptBox["H0", "4"]}], ")"}]}], "+", 
           RowBox[{"3351", " ", 
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
            SuperscriptBox["H0", "2"], " ", "Leps2"}]}], ")"}], " ", 
         "\[Beta]t"}], "+", 
        RowBox[{"1680", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
         SuperscriptBox["H0", "2"], " ", "Leps2", " ", 
         SuperscriptBox["\[Beta]t", "2"]}]}], ")"}]}], 
     RowBox[{"13475", " ", 
      SuperscriptBox["H0", "9"], " ", "Leps2"}]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dP", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"dP0", "+", 
     RowBox[{"De", "*", "dP1"}], "+", 
     RowBox[{
      RowBox[{"De", "^", "2"}], "*", "dP2"}], "+", 
     RowBox[{
      RowBox[{"De", "^", "3"}], "*", "dP3"}], "+", 
     RowBox[{
      RowBox[{"De", "^", "4"}], "*", "dP4"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dpPade", "=", 
   RowBox[{"dP0", "+", 
    RowBox[{"De", "*", 
     RowBox[{"(", 
      FractionBox[
       RowBox[{
        RowBox[{"De", "*", 
         RowBox[{"dP2", "^", "3"}]}], "+", 
        RowBox[{"dP1", "*", "dP2", "*", 
         RowBox[{"(", 
          RowBox[{"dP2", "-", 
           RowBox[{"2", "*", "De", "*", "dP3"}]}], ")"}]}], "+", 
        RowBox[{
         RowBox[{"dP1", "^", "2"}], "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"De", "*", "dP4"}], "-", "dP3"}], ")"}]}]}], 
       RowBox[{
        RowBox[{"dP2", "^", "2"}], "+", 
        RowBox[{
         RowBox[{"De", "^", "2"}], "*", 
         RowBox[{"dP3", "^", "2"}]}], "+", 
        RowBox[{"dP1", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"De", "*", "dP4"}], "-", "dP3"}], ")"}]}], "-", 
        RowBox[{"De", "*", "dP2", "*", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"De", "*", "dP4"}], "+", "dP3"}], ")"}]}]}]], ")"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"dP", ",", "dpPade"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"De", ",", "0", ",", "0.2"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Black", ",", 
      RowBox[{"{", 
       RowBox[{"Dashed", ",", "Red"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"PlotRange", "\[Rule]", "All"}]}], 
  "]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.9137021615389595`*^9, 3.913702211551129*^9}, 
   3.9137046418292403`*^9, {3.9137079474476585`*^9, 3.9137080143691454`*^9}, {
   3.9234465938033376`*^9, 3.9234466461022654`*^9}, {3.9234467102301884`*^9, 
   3.9234467144200635`*^9}, {3.92344720554117*^9, 3.923447240480176*^9}, {
   3.9235369758542023`*^9, 3.9235370227259665`*^9}, {3.9235371813007855`*^9, 
   3.923537214655284*^9}, {3.9262982245760016`*^9, 3.926298234271471*^9}, {
   3.9263004086391687`*^9, 3.926300426346439*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"6ad7716e-5fbc-49f2-8f92-6e4ef85f1313"],

Cell[BoxData[
 GraphicsBox[
  InterpretationBox[{
    TagBox[{{{}, {}, 
       TagBox[
        {GrayLevel[0], AbsoluteThickness[2], Opacity[1.], 
         LineBox[CompressedData["
1:eJwVj3s0lAkAxeVRW8mWpsyMUVtrO5VItiOkbiRnJeWZqYioNI5dqdFurUdt
yViE2GweZVFS1hp5t0Lj9Sms5zzymGQMM2a+sKG81v5xzz333D9+927yCXQ+
p6qiouKwqP89U1bObo7ctd/NWHt2oZ+Ev+q66kLKauR9sPOhLeZJ6rWCOMpX
uFra12fSR8IyO29rGMUYho4Guud7SPSP1J0NphwAgrIymgUkuDHtqkEUR4R7
3XuX0UaC3ido+4HiDd27r48yeSRalnqUf0+5iE5GwJmVOSQo7xxOxNZcR0sc
Y5vcn0SQSep7DQkH+/ln5p12k9jAjla0BsYjMmgycZ8Kic9BZxbyeElold+s
YRJK5G/ToqY2/45lpo+dkpKVcFfvsKUZpYOzhh+5w1eJVI7OekplBrwu/GRp
tEuJKbmxpv7LTOws/tmmSk2JFu/jq0Jk2bB8Xn7sSYcCCSbShJ6xx3CIWtFY
nqPAxXRekAb5BGKJesaFUAWaaHkeV3SegcdOG9F3VGD1xEITSf8TKfbiz05b
FGjr9bLh2v2Fhtc+BsafRsEviIjRKy1AtKGU2vZmFJabEsqGSriwmy8c1ssa
hWfKZpnLm0JoP7ulbhk8io81LM9Drc9hM/F2PNRuFPbjpt0iaRHWRUhtX1BH
YUTmhrjOFMOnV26hI5Xjdkr7WefZEpS+MnHtKpEj7egN53+1y3C4+LnhVLgc
W7mSG3Sdcpz2CQ4n7eSwFpN9+usrwHPRU/2wRg4a9bpVx/YXSFe/6unSJoPf
fJ1Ew/BvZEiKUsbiZbisSIjrsamEjGKdZmArg2auml+y+0uYS4Wsr6dGQF9r
cL3bvQq2Dcc6+3NGMGEd0NpjWg2R4akjNvYjSOpID48vq8YMTevaEuUwQg5n
2pbsqQGT0732UfQweHWs1fk1NfhC7a7iBnUYh6iaM37Wr9Dj0jaQmC3FN4FB
wxPNr6DdqLEwwpDiQDp30sqRh5C6Es8dSUPI5Nbqqv7DQ72Va/xS9SH4NqUc
TDpZC3qtRvfDUxJ4VdjHDL+tRf3pzvUBhYOoyK/ia12og3la8U2G4j08opZa
5IzVwfsOawWL8R7me7dWLrlUD9PK/ulo+wGwxzQPGs3VY7tW7HQZ8x1kYW9G
GOENMHObUek8J0bO+Omc0PkG+Dd0bWa39oHnX+RXwGlEgBXPnP1LD+gVg989
Wk7AmdbOrN0jwlyoOl2yksDQ4FnubkMRxFb6cn0tAhaNNL3MzSI8Jnxjs7UJ
nI+KMGCvEuFb4UBbli6BiwVZaz8OCHFkWnwy05CAWWv1r6xYIUJNewMeOi32
DSX9VLEA3p9n9/W7EMjzkVza3iWAzUvGlxuPE2hZPq1h3iTAClsP7oOTBDKV
ntscigS45/b2Y7ovAeZyM1cnjgD5bGFYWjCBwSy3wsadAiSYfTrW8+PiPpbm
TK6+AOxZ6ibGNQKql8fNOTQBLG4xealhi/wtvcl71QRoSOQvS40kMPrHRl5o
Nx9P3acEoqhFXsTBPNvXfNzR1XlKjyHwVFhyW7OaD9es40dS4gls6KKvisvl
Y4/fFT3RXQKXhO2l9g/4oBvcU9J+IzC5jOWkkcjHnLK46kQyAYHsgPBFJB/i
wq74+/cX/81VHg0M4eM/pPpzFA==
          "]]},
        Annotation[#, "Charting`Private`Tag#1"]& ], 
       TagBox[
        {RGBColor[1, 0, 0], AbsoluteThickness[2], Opacity[1.], 
         Dashing[{Small, Small}], LineBox[CompressedData["
1:eJwV0H84lAcAB3AprWKXcXUcMo1llKEipX0RVpFEESnNj93yKGmSCrGseMYw
jdzRPBhTklMJy49zHb09yVAiHK2R933vvPnZEtq7P77P9/k83/++RkERXqGq
Kioqe9j834VUbVTbZauvDlhqzX0YZBCmuqqpiquJ8je7gnRZz+icq0znfoqz
9+RyazkD++Jy03iuJb72NNf7tp/BICkLOc11QEZUUUFbDwNxaqdqJNcTPkT2
y4IOBnx5T8cJ7lFk1fV4HJQyeLI0oPY49yT8CjSC1UsZcF/u8UuTJGBdR66A
DmMQaS16pTacjJiJtzXemxisifpJ2R6Rgbu9okBnFQazkd98KJdeQfREm+EJ
YgwVX3B0RG1XceDzBcvWnDH4Luly1bXIR9etlpy84DGIknmrufUFWG+7/pNl
1mN4S1tqGDcUgohRHbVRG8OToz4fx1LFwNBxB+NuJTKtX2f2j5fAbd6sKueG
EifzpZFqzB/Q2dzhve6iEo90ywOieTdQtqL3WNlBJTQnPzxi+DfRW79ppau1
Eh0Dgc7iXbfQnB40M79cieeVP6Ya3KvE7PbCQ42vFLA3yqwZqRbDLklNuFGi
wGHhWsr7cRWab6o+JfMUmJYcO+zSfhtvTF0e6scq4DZh0/3i9R24m5hGi/0U
sGDKYve/vwtmJL56YYsCl4SdIV5z1TBW6KWc0FMgzyPRa0qrBjMpie8Oz9Ew
FQ8n8nm1ePbwwm3HIRpOQ4zceHUdtGhd+0QZDV2dBMcusz/Bi9rn7l9GQ7Ag
G1bbcB+2snXa8nQa3ysz0/ud6yHy8NXSOk1Do2yxIMe3AUey7O5nHKLB1zZP
6PZtxCnDdoszzjQmncLb+22aYG/VHffZehpXuvIvZNQ0YeZMeNaq1TRidxe6
VttK8KXQxYCziIZUdkyzQiLBTr0njYMUBRcdjfcCp2ZcI4pDJN0UTCIiRyfb
mmHvoTRMk1BwyBfPOHpKMTLRUupeQaFQ/EBP9S8pOLv1c2gRheBHwh1X/B/A
pmSlPCmZQmCdW+po3wM0m/h7DkdTqKtofM75TgZ1M0GMRwiFgJSlW0vHZdDU
2Lw/zYuC3TbT+kWnWnA1kdMZ5kQhalxjh8V8CxI2ZJoGWlGg4h+T+hdaUWNY
kjVgRKF04khp3EIrzG0cYpZpU5CG3RFUJj+ERrXZrM9iCvy6f3b+vpxAfXJt
F2eaxHzcEv6wOgGZS9/T9ikSQ47GtDGHQK52TX8G6xIiOK1Yi8DMyDUVbdYb
e//uKNIjMC1Sy+VNknD/d8i/cAPrvX7qa8dJxNkMhP+2j4Bp7UZmm5LE0dm5
7YPeBDg/tMnmFSScG/RXGvoQ4A+oFjWyXuEaIL7mT0AYah+5g3X2gb7p/GAC
DWntAW40iYqo3vi80wSmtuRHBJAkMre829t/hkB46/lba1hHzekY6Z8joB0+
Mj00SmJr0kGpKJ7A/JqA7FDWrVnPPxJdJhDkWmES8ZrEdd+3PS9SCNgVdOZa
sf5Zj3edn0qgN+g8d2qExP4iH3dhBgHNvT4GZ1nbCqINXvxC4FD6pRvbWPPN
s8d0fyUgD7V1WBhm/xu72+iXQyBYLuhrYj1U9SwjN5fdl/DiLrL+D35yd2M=

          "]]},
        Annotation[#, "Charting`Private`Tag#2"]& ]}, {}},
     {"WolframDynamicHighlight", <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>}], 
    DynamicBox[(Charting`HighlightActionBox["DynamicHighlight", {}, 
      Slot["HighlightElements"], 
      Slot["LayoutOptions"], 
      Slot["Meta"], 
      Charting`HighlightActionFunction["DynamicHighlight", {{{{}, {}, 
          Annotation[{
            Directive[
             Opacity[1.], 
             AbsoluteThickness[2], 
             GrayLevel[0]], 
            Line[CompressedData["
1:eJwVj3s0lAkAxeVRW8mWpsyMUVtrO5VItiOkbiRnJeWZqYioNI5dqdFurUdt
yViE2GweZVFS1hp5t0Lj9Sms5zzymGQMM2a+sKG81v5xzz333D9+927yCXQ+
p6qiouKwqP89U1bObo7ctd/NWHt2oZ+Ev+q66kLKauR9sPOhLeZJ6rWCOMpX
uFra12fSR8IyO29rGMUYho4Guud7SPSP1J0NphwAgrIymgUkuDHtqkEUR4R7
3XuX0UaC3ido+4HiDd27r48yeSRalnqUf0+5iE5GwJmVOSQo7xxOxNZcR0sc
Y5vcn0SQSep7DQkH+/ln5p12k9jAjla0BsYjMmgycZ8Kic9BZxbyeElold+s
YRJK5G/ToqY2/45lpo+dkpKVcFfvsKUZpYOzhh+5w1eJVI7OekplBrwu/GRp
tEuJKbmxpv7LTOws/tmmSk2JFu/jq0Jk2bB8Xn7sSYcCCSbShJ6xx3CIWtFY
nqPAxXRekAb5BGKJesaFUAWaaHkeV3SegcdOG9F3VGD1xEITSf8TKfbiz05b
FGjr9bLh2v2Fhtc+BsafRsEviIjRKy1AtKGU2vZmFJabEsqGSriwmy8c1ssa
hWfKZpnLm0JoP7ulbhk8io81LM9Drc9hM/F2PNRuFPbjpt0iaRHWRUhtX1BH
YUTmhrjOFMOnV26hI5Xjdkr7WefZEpS+MnHtKpEj7egN53+1y3C4+LnhVLgc
W7mSG3Sdcpz2CQ4n7eSwFpN9+usrwHPRU/2wRg4a9bpVx/YXSFe/6unSJoPf
fJ1Ew/BvZEiKUsbiZbisSIjrsamEjGKdZmArg2auml+y+0uYS4Wsr6dGQF9r
cL3bvQq2Dcc6+3NGMGEd0NpjWg2R4akjNvYjSOpID48vq8YMTevaEuUwQg5n
2pbsqQGT0732UfQweHWs1fk1NfhC7a7iBnUYh6iaM37Wr9Dj0jaQmC3FN4FB
wxPNr6DdqLEwwpDiQDp30sqRh5C6Es8dSUPI5Nbqqv7DQ72Va/xS9SH4NqUc
TDpZC3qtRvfDUxJ4VdjHDL+tRf3pzvUBhYOoyK/ia12og3la8U2G4j08opZa
5IzVwfsOawWL8R7me7dWLrlUD9PK/ulo+wGwxzQPGs3VY7tW7HQZ8x1kYW9G
GOENMHObUek8J0bO+Omc0PkG+Dd0bWa39oHnX+RXwGlEgBXPnP1LD+gVg989
Wk7AmdbOrN0jwlyoOl2yksDQ4FnubkMRxFb6cn0tAhaNNL3MzSI8Jnxjs7UJ
nI+KMGCvEuFb4UBbli6BiwVZaz8OCHFkWnwy05CAWWv1r6xYIUJNewMeOi32
DSX9VLEA3p9n9/W7EMjzkVza3iWAzUvGlxuPE2hZPq1h3iTAClsP7oOTBDKV
ntscigS45/b2Y7ovAeZyM1cnjgD5bGFYWjCBwSy3wsadAiSYfTrW8+PiPpbm
TK6+AOxZ6ibGNQKql8fNOTQBLG4xealhi/wtvcl71QRoSOQvS40kMPrHRl5o
Nx9P3acEoqhFXsTBPNvXfNzR1XlKjyHwVFhyW7OaD9es40dS4gls6KKvisvl
Y4/fFT3RXQKXhO2l9g/4oBvcU9J+IzC5jOWkkcjHnLK46kQyAYHsgPBFJB/i
wq74+/cX/81VHg0M4eM/pPpzFA==
             "]]}, "Charting`Private`Tag#1"], 
          Annotation[{
            Directive[
             Opacity[1.], 
             AbsoluteThickness[2], 
             Dashing[{Small, Small}], 
             RGBColor[1, 0, 0]], 
            Line[CompressedData["
1:eJwV0H84lAcAB3AprWKXcXUcMo1llKEipX0RVpFEESnNj93yKGmSCrGseMYw
jdzRPBhTklMJy49zHb09yVAiHK2R933vvPnZEtq7P77P9/k83/++RkERXqGq
Kioqe9j834VUbVTbZauvDlhqzX0YZBCmuqqpiquJ8je7gnRZz+icq0znfoqz
9+RyazkD++Jy03iuJb72NNf7tp/BICkLOc11QEZUUUFbDwNxaqdqJNcTPkT2
y4IOBnx5T8cJ7lFk1fV4HJQyeLI0oPY49yT8CjSC1UsZcF/u8UuTJGBdR66A
DmMQaS16pTacjJiJtzXemxisifpJ2R6Rgbu9okBnFQazkd98KJdeQfREm+EJ
YgwVX3B0RG1XceDzBcvWnDH4Luly1bXIR9etlpy84DGIknmrufUFWG+7/pNl
1mN4S1tqGDcUgohRHbVRG8OToz4fx1LFwNBxB+NuJTKtX2f2j5fAbd6sKueG
EifzpZFqzB/Q2dzhve6iEo90ywOieTdQtqL3WNlBJTQnPzxi+DfRW79ppau1
Eh0Dgc7iXbfQnB40M79cieeVP6Ya3KvE7PbCQ42vFLA3yqwZqRbDLklNuFGi
wGHhWsr7cRWab6o+JfMUmJYcO+zSfhtvTF0e6scq4DZh0/3i9R24m5hGi/0U
sGDKYve/vwtmJL56YYsCl4SdIV5z1TBW6KWc0FMgzyPRa0qrBjMpie8Oz9Ew
FQ8n8nm1ePbwwm3HIRpOQ4zceHUdtGhd+0QZDV2dBMcusz/Bi9rn7l9GQ7Ag
G1bbcB+2snXa8nQa3ysz0/ud6yHy8NXSOk1Do2yxIMe3AUey7O5nHKLB1zZP
6PZtxCnDdoszzjQmncLb+22aYG/VHffZehpXuvIvZNQ0YeZMeNaq1TRidxe6
VttK8KXQxYCziIZUdkyzQiLBTr0njYMUBRcdjfcCp2ZcI4pDJN0UTCIiRyfb
mmHvoTRMk1BwyBfPOHpKMTLRUupeQaFQ/EBP9S8pOLv1c2gRheBHwh1X/B/A
pmSlPCmZQmCdW+po3wM0m/h7DkdTqKtofM75TgZ1M0GMRwiFgJSlW0vHZdDU
2Lw/zYuC3TbT+kWnWnA1kdMZ5kQhalxjh8V8CxI2ZJoGWlGg4h+T+hdaUWNY
kjVgRKF04khp3EIrzG0cYpZpU5CG3RFUJj+ERrXZrM9iCvy6f3b+vpxAfXJt
F2eaxHzcEv6wOgGZS9/T9ikSQ47GtDGHQK52TX8G6xIiOK1Yi8DMyDUVbdYb
e//uKNIjMC1Sy+VNknD/d8i/cAPrvX7qa8dJxNkMhP+2j4Bp7UZmm5LE0dm5
7YPeBDg/tMnmFSScG/RXGvoQ4A+oFjWyXuEaIL7mT0AYah+5g3X2gb7p/GAC
DWntAW40iYqo3vi80wSmtuRHBJAkMre829t/hkB46/lba1hHzekY6Z8joB0+
Mj00SmJr0kGpKJ7A/JqA7FDWrVnPPxJdJhDkWmES8ZrEdd+3PS9SCNgVdOZa
sf5Zj3edn0qgN+g8d2qExP4iH3dhBgHNvT4GZ1nbCqINXvxC4FD6pRvbWPPN
s8d0fyUgD7V1WBhm/xu72+iXQyBYLuhrYj1U9SwjN5fdl/DiLrL+D35yd2M=

             "]]}, "Charting`Private`Tag#2"]}}, {}}, <|
       "HighlightElements" -> <|
         "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
        "LayoutOptions" -> <|
         "PlotRange" -> {All, All}, 
          "Frame" -> {{False, False}, {False, False}}, 
          "AxesOrigin" -> {0, 0.3669698971716267}, 
          "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
          "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
            Directive[
             Opacity[1.], 
             AbsoluteThickness[2], 
             Dashing[{Small, Small}], 
             RGBColor[1, 0, 0]], 
            Directive[
             Opacity[1.], 
             AbsoluteThickness[2], 
             GrayLevel[0]]}, 
          "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
              Identity[
               Part[#, 1]], 
              Identity[
               Part[#, 2]]}& ), 
            "ScalingFunctions" -> {{Identity, Identity}, {
              Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>,
         "Meta" -> <|
         "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
          Plot, "GroupHighlight" -> False|>|>]]& )[<|
      "HighlightElements" -> <|
        "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
       "LayoutOptions" -> <|
        "PlotRange" -> {All, All}, 
         "Frame" -> {{False, False}, {False, False}}, 
         "AxesOrigin" -> {0, 0.3669698971716267}, 
         "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
         "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
           Directive[
            Opacity[1.], 
            AbsoluteThickness[2], 
            Dashing[{Small, Small}], 
            RGBColor[1, 0, 0]], 
           Directive[
            Opacity[1.], 
            AbsoluteThickness[2], 
            GrayLevel[0]]}, 
         "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
             Identity[
              Part[#, 1]], 
             Identity[
              Part[#, 2]]}& ), 
           "ScalingFunctions" -> {{Identity, Identity}, {
             Identity, Identity}}|>, "Primitives" -> {}, "GCFlag" -> False|>, 
       "Meta" -> <|
        "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
         Plot, "GroupHighlight" -> False|>|>],
     ImageSizeCache->{{4.503599627370496*^15, -4.503599627370496*^15}, {
      4.503599627370496*^15, -4.503599627370496*^15}}]},
   Annotation[{{{{}, {}, 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          GrayLevel[0]], 
         Line[CompressedData["
1:eJwVj3s0lAkAxeVRW8mWpsyMUVtrO5VItiOkbiRnJeWZqYioNI5dqdFurUdt
yViE2GweZVFS1hp5t0Lj9Sms5zzymGQMM2a+sKG81v5xzz333D9+927yCXQ+
p6qiouKwqP89U1bObo7ctd/NWHt2oZ+Ev+q66kLKauR9sPOhLeZJ6rWCOMpX
uFra12fSR8IyO29rGMUYho4Guud7SPSP1J0NphwAgrIymgUkuDHtqkEUR4R7
3XuX0UaC3ido+4HiDd27r48yeSRalnqUf0+5iE5GwJmVOSQo7xxOxNZcR0sc
Y5vcn0SQSep7DQkH+/ln5p12k9jAjla0BsYjMmgycZ8Kic9BZxbyeElold+s
YRJK5G/ToqY2/45lpo+dkpKVcFfvsKUZpYOzhh+5w1eJVI7OekplBrwu/GRp
tEuJKbmxpv7LTOws/tmmSk2JFu/jq0Jk2bB8Xn7sSYcCCSbShJ6xx3CIWtFY
nqPAxXRekAb5BGKJesaFUAWaaHkeV3SegcdOG9F3VGD1xEITSf8TKfbiz05b
FGjr9bLh2v2Fhtc+BsafRsEviIjRKy1AtKGU2vZmFJabEsqGSriwmy8c1ssa
hWfKZpnLm0JoP7ulbhk8io81LM9Drc9hM/F2PNRuFPbjpt0iaRHWRUhtX1BH
YUTmhrjOFMOnV26hI5Xjdkr7WefZEpS+MnHtKpEj7egN53+1y3C4+LnhVLgc
W7mSG3Sdcpz2CQ4n7eSwFpN9+usrwHPRU/2wRg4a9bpVx/YXSFe/6unSJoPf
fJ1Ew/BvZEiKUsbiZbisSIjrsamEjGKdZmArg2auml+y+0uYS4Wsr6dGQF9r
cL3bvQq2Dcc6+3NGMGEd0NpjWg2R4akjNvYjSOpID48vq8YMTevaEuUwQg5n
2pbsqQGT0732UfQweHWs1fk1NfhC7a7iBnUYh6iaM37Wr9Dj0jaQmC3FN4FB
wxPNr6DdqLEwwpDiQDp30sqRh5C6Es8dSUPI5Nbqqv7DQ72Va/xS9SH4NqUc
TDpZC3qtRvfDUxJ4VdjHDL+tRf3pzvUBhYOoyK/ia12og3la8U2G4j08opZa
5IzVwfsOawWL8R7me7dWLrlUD9PK/ulo+wGwxzQPGs3VY7tW7HQZ8x1kYW9G
GOENMHObUek8J0bO+Omc0PkG+Dd0bWa39oHnX+RXwGlEgBXPnP1LD+gVg989
Wk7AmdbOrN0jwlyoOl2yksDQ4FnubkMRxFb6cn0tAhaNNL3MzSI8Jnxjs7UJ
nI+KMGCvEuFb4UBbli6BiwVZaz8OCHFkWnwy05CAWWv1r6xYIUJNewMeOi32
DSX9VLEA3p9n9/W7EMjzkVza3iWAzUvGlxuPE2hZPq1h3iTAClsP7oOTBDKV
ntscigS45/b2Y7ovAeZyM1cnjgD5bGFYWjCBwSy3wsadAiSYfTrW8+PiPpbm
TK6+AOxZ6ibGNQKql8fNOTQBLG4xealhi/wtvcl71QRoSOQvS40kMPrHRl5o
Nx9P3acEoqhFXsTBPNvXfNzR1XlKjyHwVFhyW7OaD9es40dS4gls6KKvisvl
Y4/fFT3RXQKXhO2l9g/4oBvcU9J+IzC5jOWkkcjHnLK46kQyAYHsgPBFJB/i
wq74+/cX/81VHg0M4eM/pPpzFA==
          "]]}, "Charting`Private`Tag#1"], 
       Annotation[{
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          Dashing[{Small, Small}], 
          RGBColor[1, 0, 0]], 
         Line[CompressedData["
1:eJwV0H84lAcAB3AprWKXcXUcMo1llKEipX0RVpFEESnNj93yKGmSCrGseMYw
jdzRPBhTklMJy49zHb09yVAiHK2R933vvPnZEtq7P77P9/k83/++RkERXqGq
Kioqe9j834VUbVTbZauvDlhqzX0YZBCmuqqpiquJ8je7gnRZz+icq0znfoqz
9+RyazkD++Jy03iuJb72NNf7tp/BICkLOc11QEZUUUFbDwNxaqdqJNcTPkT2
y4IOBnx5T8cJ7lFk1fV4HJQyeLI0oPY49yT8CjSC1UsZcF/u8UuTJGBdR66A
DmMQaS16pTacjJiJtzXemxisifpJ2R6Rgbu9okBnFQazkd98KJdeQfREm+EJ
YgwVX3B0RG1XceDzBcvWnDH4Luly1bXIR9etlpy84DGIknmrufUFWG+7/pNl
1mN4S1tqGDcUgohRHbVRG8OToz4fx1LFwNBxB+NuJTKtX2f2j5fAbd6sKueG
EifzpZFqzB/Q2dzhve6iEo90ywOieTdQtqL3WNlBJTQnPzxi+DfRW79ppau1
Eh0Dgc7iXbfQnB40M79cieeVP6Ya3KvE7PbCQ42vFLA3yqwZqRbDLklNuFGi
wGHhWsr7cRWab6o+JfMUmJYcO+zSfhtvTF0e6scq4DZh0/3i9R24m5hGi/0U
sGDKYve/vwtmJL56YYsCl4SdIV5z1TBW6KWc0FMgzyPRa0qrBjMpie8Oz9Ew
FQ8n8nm1ePbwwm3HIRpOQ4zceHUdtGhd+0QZDV2dBMcusz/Bi9rn7l9GQ7Ag
G1bbcB+2snXa8nQa3ysz0/ud6yHy8NXSOk1Do2yxIMe3AUey7O5nHKLB1zZP
6PZtxCnDdoszzjQmncLb+22aYG/VHffZehpXuvIvZNQ0YeZMeNaq1TRidxe6
VttK8KXQxYCziIZUdkyzQiLBTr0njYMUBRcdjfcCp2ZcI4pDJN0UTCIiRyfb
mmHvoTRMk1BwyBfPOHpKMTLRUupeQaFQ/EBP9S8pOLv1c2gRheBHwh1X/B/A
pmSlPCmZQmCdW+po3wM0m/h7DkdTqKtofM75TgZ1M0GMRwiFgJSlW0vHZdDU
2Lw/zYuC3TbT+kWnWnA1kdMZ5kQhalxjh8V8CxI2ZJoGWlGg4h+T+hdaUWNY
kjVgRKF04khp3EIrzG0cYpZpU5CG3RFUJj+ERrXZrM9iCvy6f3b+vpxAfXJt
F2eaxHzcEv6wOgGZS9/T9ikSQ47GtDGHQK52TX8G6xIiOK1Yi8DMyDUVbdYb
e//uKNIjMC1Sy+VNknD/d8i/cAPrvX7qa8dJxNkMhP+2j4Bp7UZmm5LE0dm5
7YPeBDg/tMnmFSScG/RXGvoQ4A+oFjWyXuEaIL7mT0AYah+5g3X2gb7p/GAC
DWntAW40iYqo3vi80wSmtuRHBJAkMre829t/hkB46/lba1hHzekY6Z8joB0+
Mj00SmJr0kGpKJ7A/JqA7FDWrVnPPxJdJhDkWmES8ZrEdd+3PS9SCNgVdOZa
sf5Zj3edn0qgN+g8d2qExP4iH3dhBgHNvT4GZ1nbCqINXvxC4FD6pRvbWPPN
s8d0fyUgD7V1WBhm/xu72+iXQyBYLuhrYj1U9SwjN5fdl/DiLrL+D35yd2M=

          "]]}, "Charting`Private`Tag#2"]}}, {}}, <|
    "HighlightElements" -> <|
      "Label" -> {"XYLabel"}, "Ball" -> {"InterpolatedBall"}|>, 
     "LayoutOptions" -> <|
      "PlotRange" -> {All, All}, "Frame" -> {{False, False}, {False, False}}, 
       "AxesOrigin" -> {0, 0.3669698971716267}, 
       "ImageSize" -> {360, 360/GoldenRatio}, "Axes" -> {True, True}, 
       "AspectRatio" -> GoldenRatio^(-1), "DefaultStyle" -> {
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          Dashing[{Small, Small}], 
          RGBColor[1, 0, 0]], 
         Directive[
          Opacity[1.], 
          AbsoluteThickness[2], 
          GrayLevel[0]]}, 
       "HighlightLabelingFunctions" -> <|"CoordinatesToolOptions" -> ({
           Identity[
            Part[#, 1]], 
           Identity[
            Part[#, 2]]}& ), 
         "ScalingFunctions" -> {{Identity, Identity}, {Identity, Identity}}|>,
        "Primitives" -> {}, "GCFlag" -> False|>, 
     "Meta" -> <|
      "DefaultHighlight" -> {"Dynamic", None}, "Index" -> {}, "Function" -> 
       Plot, "GroupHighlight" -> False|>|>, "DynamicHighlight"]],
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.3669698971716267},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.9137022277275314`*^9, 3.913704654928465*^9, {3.9137079861148233`*^9, 
   3.9137080321741405`*^9}, 3.923446661622856*^9, 3.9234467363554*^9, 
   3.923447250255742*^9, 3.9235370434102216`*^9, 3.923537229268116*^9, {
   3.926300412947496*^9, 3.926300428302414*^9}},
 CellLabel->"Out[25]=",ExpressionUUID->"f9b800d0-e58d-43b4-91cf-c339664331c9"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   StyleBox["Pressure", "Title"], 
   StyleBox[" ", "Title"], 
   StyleBox["drop", "Title"], 
   StyleBox[" ", "Title"], 
   StyleBox["limit", "Title"], 
   StyleBox[" ", "Title"], 
   StyleBox["of", "Title"], 
   StyleBox[" ", "Title"], 
   StyleBox[
    RowBox[{"h", 
     StyleBox["igh", "Title"]}]], 
   StyleBox[" ", "Title"], 
   StyleBox[
    SuperscriptBox["L", "2"], "Title"], 
   StyleBox[" ", "Title"], 
   StyleBox[
    SuperscriptBox["\[Epsilon]", "2"], "Title"]}], 
  StyleBox["-", "Title"], 
  StyleBox[" ", "Title"], 
  StyleBox[
   RowBox[{"(", 
    RowBox[{"Oldroyd", "-", 
     RowBox[{"B", " ", "limit"}]}], ")"}], "Title"]}]], "Title",
 CellChangeTimes->{{3.923446316164901*^9, 3.9234463574642973`*^9}, {
   3.923446400343753*^9, 3.923446469337562*^9}, {3.923447318835846*^9, 
   3.923447383740822*^9}, {3.9234477279011984`*^9, 3.9234477421153436`*^9}, {
   3.9234478188165455`*^9, 3.9234478412219667`*^9}, 3.924419751957941*^9, 
   3.930650852727604*^9, {3.930650883448797*^9, 
   3.9306508986673684`*^9}},ExpressionUUID->"f0942bd9-2492-4ac2-bdd1-\
d6aa69ff9ff5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Leps2", "=", 
     RowBox[{
      SuperscriptBox["L", "2"], " ", 
      SuperscriptBox["\[Epsilon]", "2"]}]}], ";"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"dP0", "=", 
    RowBox[{"FullSimplify", "[", 
     FractionBox[
      RowBox[{"3", " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "H0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["H0", "2"]}], ")"}]}], 
      RowBox[{"4", " ", 
       SuperscriptBox["H0", "3"]}]], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"dP1", "=", 
    RowBox[{"FullSimplify", "[", 
     RowBox[{
      FractionBox["9", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "1"}], "+", 
        FractionBox["1", 
         SuperscriptBox["H0", "4"]]}], ")"}], " ", "\[Beta]t"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"dP2", "=", 
    RowBox[{"FullSimplify", "[", 
     FractionBox[
      RowBox[{"648", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "H0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["H0", "2"]}], ")"}], " ", "\[Beta]t"}], 
      RowBox[{"35", " ", 
       SuperscriptBox["H0", "5"]}]], "]"}]}], "\[IndentingNewLine]", 
   RowBox[{"dP3", "=", 
    RowBox[{"FullSimplify", "[", 
     FractionBox[
      RowBox[{"27", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox["H0", "4"]}], ")"}], " ", "\[Beta]t", " ", 
       RowBox[{"(", 
        RowBox[{"99", "+", 
         RowBox[{
          SuperscriptBox["H0", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"99", " ", 
             SuperscriptBox["H0", "2"]}], "-", 
            RowBox[{"176", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", "Leps2"}], 
            "+", 
            RowBox[{"16", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", "Leps2", 
             " ", "\[Beta]t"}]}], ")"}]}]}], ")"}]}], 
      RowBox[{"70", " ", 
       SuperscriptBox["H0", "8"], " ", "Leps2"}]], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"dP4", "=", 
    RowBox[{"FullSimplify", "[", 
     FractionBox[
      RowBox[{"162", " ", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", "H0"}], ")"}], " ", 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         SuperscriptBox["H0", "2"]}], ")"}], " ", "\[Beta]t", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "53515"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            SuperscriptBox["H0", "4"]}], ")"}]}], "+", 
         RowBox[{"19600", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
          SuperscriptBox["H0", "2"], " ", "Leps2"}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"6160", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", 
               SuperscriptBox["H0", "4"]}], ")"}]}], "+", 
            RowBox[{"3351", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
             SuperscriptBox["H0", "2"], " ", "Leps2"}]}], ")"}], " ", 
          "\[Beta]t"}], "+", 
         RowBox[{"1680", " ", 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
          SuperscriptBox["H0", "2"], " ", "Leps2", " ", 
          SuperscriptBox["\[Beta]t", "2"]}]}], ")"}]}], 
      RowBox[{"13475", " ", 
       SuperscriptBox["H0", "9"], " ", "Leps2"}]], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Limit", "[", 
     RowBox[{"dP3", ",", 
      RowBox[{"{", 
       RowBox[{"Leps2", " ", "->", " ", "\[Infinity]"}], "}"}]}], "]"}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Limit", "[", 
     RowBox[{"dP4", ",", 
      RowBox[{"{", 
       RowBox[{"Leps2", " ", "->", " ", "\[Infinity]"}], "}"}]}], "]"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.9234474624996147`*^9, 3.9234474640032177`*^9}, 
   3.923537126414692*^9, {3.923537265817941*^9, 3.9235372667389483`*^9}, {
   3.923643378012615*^9, 3.9236433884936004`*^9}, {3.9236434503274136`*^9, 
   3.9236434512915163`*^9}, {3.9236434995907035`*^9, 
   3.9236435044047995`*^9}, {3.92364353518652*^9, 3.923643639984147*^9}, {
   3.9236436771277695`*^9, 3.92364368598755*^9}, {3.9236437184855266`*^9, 
   3.9236437209902577`*^9}, {3.923643769250925*^9, 3.9236438158330064`*^9}, {
   3.923643923408443*^9, 3.9236440005875173`*^9}, {3.9236442242402544`*^9, 
   3.9236442288133273`*^9}, {3.9306508645840545`*^9, 3.9306508720027113`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"9d447b61-e933-44c8-a73a-e072bae8cbee"],

Cell[BoxData[
 FractionBox[
  RowBox[{"3", " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "H0"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["H0", "2"]}], ")"}]}], 
  RowBox[{"4", " ", 
   SuperscriptBox["H0", "3"]}]]], "Output",
 CellChangeTimes->{
  3.9234474749794006`*^9, 3.9235371383470984`*^9, 3.9235372747379293`*^9, 
   3.9236434017745347`*^9, 3.9236435167642846`*^9, 3.9236435515141907`*^9, 
   3.923643581949789*^9, 3.9236436483186927`*^9, 3.9236436936800275`*^9, 
   3.9236437293484116`*^9, 3.9236438237289596`*^9, {3.923643928676143*^9, 
   3.923644002369014*^9}, 3.923644237243353*^9, 3.9306508784317017`*^9},
 CellLabel->"Out[1]=",ExpressionUUID->"e449b4f3-314b-4fce-92db-b4b4386f7b7a"],

Cell[BoxData[
 RowBox[{
  FractionBox["9", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"-", "1"}], "+", 
    FractionBox["1", 
     SuperscriptBox["H0", "4"]]}], ")"}], " ", "\[Beta]t"}]], "Output",
 CellChangeTimes->{
  3.9234474749794006`*^9, 3.9235371383470984`*^9, 3.9235372747379293`*^9, 
   3.9236434017745347`*^9, 3.9236435167642846`*^9, 3.9236435515141907`*^9, 
   3.923643581949789*^9, 3.9236436483186927`*^9, 3.9236436936800275`*^9, 
   3.9236437293484116`*^9, 3.9236438237289596`*^9, {3.923643928676143*^9, 
   3.923644002369014*^9}, 3.923644237243353*^9, 3.930650878462666*^9},
 CellLabel->"Out[2]=",ExpressionUUID->"839a4eef-9489-4e91-be99-150134c13424"],

Cell[BoxData[
 FractionBox[
  RowBox[{"648", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "H0"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["H0", "2"]}], ")"}], " ", "\[Beta]t"}], 
  RowBox[{"35", " ", 
   SuperscriptBox["H0", "5"]}]]], "Output",
 CellChangeTimes->{
  3.9234474749794006`*^9, 3.9235371383470984`*^9, 3.9235372747379293`*^9, 
   3.9236434017745347`*^9, 3.9236435167642846`*^9, 3.9236435515141907`*^9, 
   3.923643581949789*^9, 3.9236436483186927`*^9, 3.9236436936800275`*^9, 
   3.9236437293484116`*^9, 3.9236438237289596`*^9, {3.923643928676143*^9, 
   3.923644002369014*^9}, 3.923644237243353*^9, 3.930650878462666*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"88dfd7fc-2ce8-4968-8e3c-0654dbf1db41"],

Cell[BoxData[
 FractionBox[
  RowBox[{"27", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "1"}], "+", 
     SuperscriptBox["H0", "4"]}], ")"}], " ", "\[Beta]t", " ", 
   RowBox[{"(", 
    RowBox[{"99", "+", 
     RowBox[{
      SuperscriptBox["H0", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"99", " ", 
         SuperscriptBox["H0", "2"]}], "-", 
        RowBox[{"176", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", "Leps2"}], "+", 
        RowBox[{"16", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", "Leps2", " ", 
         "\[Beta]t"}]}], ")"}]}]}], ")"}]}], 
  RowBox[{"70", " ", 
   SuperscriptBox["H0", "8"], " ", "Leps2"}]]], "Output",
 CellChangeTimes->{
  3.9234474749794006`*^9, 3.9235371383470984`*^9, 3.9235372747379293`*^9, 
   3.9236434017745347`*^9, 3.9236435167642846`*^9, 3.9236435515141907`*^9, 
   3.923643581949789*^9, 3.9236436483186927`*^9, 3.9236436936800275`*^9, 
   3.9236437293484116`*^9, 3.9236438237289596`*^9, {3.923643928676143*^9, 
   3.923644002369014*^9}, 3.923644237243353*^9, 3.930650878525467*^9},
 CellLabel->"Out[4]=",ExpressionUUID->"e4a14656-7c86-41a9-ad77-bde0fb49897c"],

Cell[BoxData[
 FractionBox[
  RowBox[{"162", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "H0"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["H0", "2"]}], ")"}], " ", "\[Beta]t", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "53515"}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "+", 
        SuperscriptBox["H0", "4"]}], ")"}]}], "+", 
     RowBox[{"19600", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
      SuperscriptBox["H0", "2"], " ", "Leps2"}], "-", 
     RowBox[{"2", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"6160", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", 
           SuperscriptBox["H0", "4"]}], ")"}]}], "+", 
        RowBox[{"3351", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
         SuperscriptBox["H0", "2"], " ", "Leps2"}]}], ")"}], " ", 
      "\[Beta]t"}], "+", 
     RowBox[{"1680", " ", 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "1"}], "+", "H0"}], ")"}], "2"], " ", 
      SuperscriptBox["H0", "2"], " ", "Leps2", " ", 
      SuperscriptBox["\[Beta]t", "2"]}]}], ")"}]}], 
  RowBox[{"13475", " ", 
   SuperscriptBox["H0", "9"], " ", "Leps2"}]]], "Output",
 CellChangeTimes->{
  3.9234474749794006`*^9, 3.9235371383470984`*^9, 3.9235372747379293`*^9, 
   3.9236434017745347`*^9, 3.9236435167642846`*^9, 3.9236435515141907`*^9, 
   3.923643581949789*^9, 3.9236436483186927`*^9, 3.9236436936800275`*^9, 
   3.9236437293484116`*^9, 3.9236438237289596`*^9, {3.923643928676143*^9, 
   3.923644002369014*^9}, 3.923644237243353*^9, 3.9306508786518745`*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"6a4c94a8-b7b7-4018-bef1-9a7f3b695566"],

Cell[BoxData[
 FractionBox[
  RowBox[{"216", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "H0"}], ")"}], "3"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "H0"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["H0", "2"]}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", "11"}], "+", "\[Beta]t"}], ")"}], " ", "\[Beta]t"}], 
  RowBox[{"35", " ", 
   SuperscriptBox["H0", "6"]}]]], "Output",
 CellChangeTimes->{
  3.9234474749794006`*^9, 3.9235371383470984`*^9, 3.9235372747379293`*^9, 
   3.9236434017745347`*^9, 3.9236435167642846`*^9, 3.9236435515141907`*^9, 
   3.923643581949789*^9, 3.9236436483186927`*^9, 3.9236436936800275`*^9, 
   3.9236437293484116`*^9, 3.9236438237289596`*^9, {3.923643928676143*^9, 
   3.923644002369014*^9}, 3.923644237243353*^9, 3.9306508788565464`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"c7e698cf-be9f-4161-b5fc-6cde5cf78c80"],

Cell[BoxData[
 FractionBox[
  RowBox[{"324", " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      RowBox[{"-", "1"}], "+", "H0"}], ")"}], "4"], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", "H0"}], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{"1", "+", 
     SuperscriptBox["H0", "2"]}], ")"}], " ", "\[Beta]t", " ", 
   RowBox[{"(", 
    RowBox[{"9800", "-", 
     RowBox[{"3351", " ", "\[Beta]t"}], "+", 
     RowBox[{"840", " ", 
      SuperscriptBox["\[Beta]t", "2"]}]}], ")"}]}], 
  RowBox[{"13475", " ", 
   SuperscriptBox["H0", "7"]}]]], "Output",
 CellChangeTimes->{
  3.9234474749794006`*^9, 3.9235371383470984`*^9, 3.9235372747379293`*^9, 
   3.9236434017745347`*^9, 3.9236435167642846`*^9, 3.9236435515141907`*^9, 
   3.923643581949789*^9, 3.9236436483186927`*^9, 3.9236436936800275`*^9, 
   3.9236437293484116`*^9, 3.9236438237289596`*^9, {3.923643928676143*^9, 
   3.923644002369014*^9}, 3.923644237243353*^9, 3.9306508788884273`*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"1e596611-edcd-4ed5-958f-cf2805e0658e"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{949, 527},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
TaggingRules-><|"TryRealOnly" -> False|>,
Magnification:>1.05 Inherited,
FrontEndVersion->"13.3 for Microsoft Windows (64-bit) (June 3, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"29c57347-b7ae-471a-af33-c401318e40eb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 388, 11, 105, "Title",ExpressionUUID->"dbc62d93-449a-4266-8f5f-1c83689d4c88"],
Cell[971, 35, 2351, 49, 173, "Text",ExpressionUUID->"42b92100-7780-43c5-94be-ff71f092ad71"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3359, 89, 278, 4, 102, "Title",ExpressionUUID->"a5a05402-7c96-45c6-924a-d2888b544da6"],
Cell[CellGroupData[{
Cell[3662, 97, 6834, 184, 533, "Input",ExpressionUUID->"830a6b97-8ec7-4883-adfc-d60dd038f50b"],
Cell[10499, 283, 822, 12, 33, "Output",ExpressionUUID->"e326d2cf-f52c-41c9-9d28-51d4908e1e99"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[11370, 301, 222, 4, 102, "Title",ExpressionUUID->"87b5e66b-9103-4afc-9346-b706941f3a0b"],
Cell[CellGroupData[{
Cell[11617, 309, 15186, 414, 979, "Input",ExpressionUUID->"3ff51b4c-7960-4473-b3fb-911becd55d1d"],
Cell[26806, 725, 574, 8, 33, "Output",ExpressionUUID->"83419dae-57e8-4a64-becd-bb10cfb92b7b"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[27429, 739, 244, 4, 102, "Title",ExpressionUUID->"27630eb1-f5ef-4202-a0c4-c30c85a00093"],
Cell[CellGroupData[{
Cell[27698, 747, 20376, 576, 1210, "Input",ExpressionUUID->"09ea0d15-b582-472e-a2dd-7c440edbcc14"],
Cell[48077, 1325, 455, 6, 33, "Output",ExpressionUUID->"358428bb-802d-4e0b-a447-034581b7698d"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[48581, 1337, 223, 4, 102, "Title",ExpressionUUID->"112f3e4a-2b79-4731-b2bc-8602d7c1939e"],
Cell[CellGroupData[{
Cell[48829, 1345, 39059, 1104, 1884, "Input",ExpressionUUID->"5b387132-769d-40ae-8e7b-bbbe9affae5d"],
Cell[87891, 2451, 271, 4, 33, "Output",ExpressionUUID->"754f9dde-9b31-4252-9e21-2b16763c56dc"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[88211, 2461, 326, 5, 102, "Title",ExpressionUUID->"bfd22989-1cfe-4eca-800d-489d4620359f"],
Cell[CellGroupData[{
Cell[88562, 2470, 86499, 2415, 3847, "Input",ExpressionUUID->"2f23cd0c-99f6-4820-b91c-a2c2acf1d8b7"],
Cell[175064, 4887, 149, 2, 33, "Output",ExpressionUUID->"518d760e-7524-43a2-8ba7-7568808573f4"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[175262, 4895, 412, 6, 102, "Title",ExpressionUUID->"13c6c320-1d45-4fec-bf7e-17725cacf49c"],
Cell[CellGroupData[{
Cell[175699, 4905, 287, 4, 70, "Section",ExpressionUUID->"251ea895-0ad8-43e0-aa4e-d418cc4a8df5"],
Cell[CellGroupData[{
Cell[176011, 4913, 12964, 388, 580, "Input",ExpressionUUID->"b28b0f00-813a-4d6e-a923-2cc28c9a7469"],
Cell[188978, 5303, 589, 14, 55, "Output",ExpressionUUID->"f34b9e4c-cb0b-49a9-8e6d-d64d1e40a02b"],
Cell[189570, 5319, 540, 12, 50, "Output",ExpressionUUID->"53cdc1b5-235f-4ef7-b6b5-0e59cb8dabb6"],
Cell[190113, 5333, 720, 18, 55, "Output",ExpressionUUID->"37fbd7a5-365d-4ba4-ba35-84767d96fb1e"],
Cell[190836, 5353, 1187, 32, 58, "Output",ExpressionUUID->"b5ce825c-28a0-4b78-ab3f-2c27aabb625c"],
Cell[192026, 5387, 1829, 52, 78, "Output",ExpressionUUID->"73a37db8-a10b-4e5f-a1b6-805d3499f597"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[193916, 5446, 223, 4, 102, "Title",ExpressionUUID->"d860aeed-efd9-4108-92e1-34429f0f53e6"],
Cell[CellGroupData[{
Cell[194164, 5454, 6578, 193, 476, "Input",ExpressionUUID->"6ad7716e-5fbc-49f2-8f92-6e4ef85f1313"],
Cell[200745, 5649, 16999, 346, 247, "Output",ExpressionUUID->"f9b800d0-e58d-43b4-91cf-c339664331c9"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[217793, 6001, 1120, 32, 167, "Title",ExpressionUUID->"f0942bd9-2492-4ac2-bdd1-d6aa69ff9ff5"],
Cell[CellGroupData[{
Cell[218938, 6037, 5356, 148, 373, "Input",ExpressionUUID->"9d447b61-e933-44c8-a73a-e072bae8cbee"],
Cell[224297, 6187, 728, 16, 55, "Output",ExpressionUUID->"e449b4f3-314b-4fce-92db-b4b4386f7b7a"],
Cell[225028, 6205, 675, 14, 50, "Output",ExpressionUUID->"839a4eef-9489-4e91-be99-150134c13424"],
Cell[225706, 6221, 855, 20, 55, "Output",ExpressionUUID->"88dfd7fc-2ce8-4968-8e3c-0654dbf1db41"],
Cell[226564, 6243, 1324, 34, 58, "Output",ExpressionUUID->"e4a14656-7c86-41a9-ad77-bde0fb49897c"],
Cell[227891, 6279, 1966, 54, 78, "Output",ExpressionUUID->"6a4c94a8-b7b7-4018-bef1-9a7f3b695566"],
Cell[229860, 6335, 945, 23, 55, "Output",ExpressionUUID->"c7e698cf-be9f-4161-b5fc-6cde5cf78c80"],
Cell[230808, 6360, 1031, 25, 55, "Output",ExpressionUUID->"1e596611-edcd-4ed5-958f-cf2805e0658e"]
}, Open  ]]
}, Open  ]]
}
]
*)

